# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ClusterMigrateToNativeVcnStatus(object):
    """
    Information regarding a cluster's move to Native VCN.
    """

    #: A constant which can be used with the state property of a ClusterMigrateToNativeVcnStatus.
    #: This constant has a value of "NOT_STARTED"
    STATE_NOT_STARTED = "NOT_STARTED"

    #: A constant which can be used with the state property of a ClusterMigrateToNativeVcnStatus.
    #: This constant has a value of "REQUESTED"
    STATE_REQUESTED = "REQUESTED"

    #: A constant which can be used with the state property of a ClusterMigrateToNativeVcnStatus.
    #: This constant has a value of "IN_PROGRESS"
    STATE_IN_PROGRESS = "IN_PROGRESS"

    #: A constant which can be used with the state property of a ClusterMigrateToNativeVcnStatus.
    #: This constant has a value of "PENDING_DECOMMISSION"
    STATE_PENDING_DECOMMISSION = "PENDING_DECOMMISSION"

    #: A constant which can be used with the state property of a ClusterMigrateToNativeVcnStatus.
    #: This constant has a value of "COMPLETED"
    STATE_COMPLETED = "COMPLETED"

    def __init__(self, **kwargs):
        """
        Initializes a new ClusterMigrateToNativeVcnStatus object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param time_decommission_scheduled:
            The value to assign to the time_decommission_scheduled property of this ClusterMigrateToNativeVcnStatus.
        :type time_decommission_scheduled: datetime

        :param state:
            The value to assign to the state property of this ClusterMigrateToNativeVcnStatus.
            Allowed values for this property are: "NOT_STARTED", "REQUESTED", "IN_PROGRESS", "PENDING_DECOMMISSION", "COMPLETED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type state: str

        """
        self.swagger_types = {
            'time_decommission_scheduled': 'datetime',
            'state': 'str'
        }

        self.attribute_map = {
            'time_decommission_scheduled': 'timeDecommissionScheduled',
            'state': 'state'
        }

        self._time_decommission_scheduled = None
        self._state = None

    @property
    def time_decommission_scheduled(self):
        """
        Gets the time_decommission_scheduled of this ClusterMigrateToNativeVcnStatus.
        The date and time the non-native VCN is due to be decommissioned.


        :return: The time_decommission_scheduled of this ClusterMigrateToNativeVcnStatus.
        :rtype: datetime
        """
        return self._time_decommission_scheduled

    @time_decommission_scheduled.setter
    def time_decommission_scheduled(self, time_decommission_scheduled):
        """
        Sets the time_decommission_scheduled of this ClusterMigrateToNativeVcnStatus.
        The date and time the non-native VCN is due to be decommissioned.


        :param time_decommission_scheduled: The time_decommission_scheduled of this ClusterMigrateToNativeVcnStatus.
        :type: datetime
        """
        self._time_decommission_scheduled = time_decommission_scheduled

    @property
    def state(self):
        """
        **[Required]** Gets the state of this ClusterMigrateToNativeVcnStatus.
        The current migration status of the cluster.

        Allowed values for this property are: "NOT_STARTED", "REQUESTED", "IN_PROGRESS", "PENDING_DECOMMISSION", "COMPLETED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The state of this ClusterMigrateToNativeVcnStatus.
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """
        Sets the state of this ClusterMigrateToNativeVcnStatus.
        The current migration status of the cluster.


        :param state: The state of this ClusterMigrateToNativeVcnStatus.
        :type: str
        """
        allowed_values = ["NOT_STARTED", "REQUESTED", "IN_PROGRESS", "PENDING_DECOMMISSION", "COMPLETED"]
        if not value_allowed_none_or_none_sentinel(state, allowed_values):
            state = 'UNKNOWN_ENUM_VALUE'
        self._state = state

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class JobScheduleDetails(object):
    """
    The details of the job schedule.
    """

    #: A constant which can be used with the interval_type property of a JobScheduleDetails.
    #: This constant has a value of "DAILY"
    INTERVAL_TYPE_DAILY = "DAILY"

    #: A constant which can be used with the interval_type property of a JobScheduleDetails.
    #: This constant has a value of "HOURLY"
    INTERVAL_TYPE_HOURLY = "HOURLY"

    #: A constant which can be used with the interval_type property of a JobScheduleDetails.
    #: This constant has a value of "WEEKLY"
    INTERVAL_TYPE_WEEKLY = "WEEKLY"

    #: A constant which can be used with the interval_type property of a JobScheduleDetails.
    #: This constant has a value of "MONTHLY"
    INTERVAL_TYPE_MONTHLY = "MONTHLY"

    #: A constant which can be used with the interval_type property of a JobScheduleDetails.
    #: This constant has a value of "NEVER"
    INTERVAL_TYPE_NEVER = "NEVER"

    def __init__(self, **kwargs):
        """
        Initializes a new JobScheduleDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param start_time:
            The value to assign to the start_time property of this JobScheduleDetails.
        :type start_time: str

        :param end_time:
            The value to assign to the end_time property of this JobScheduleDetails.
        :type end_time: str

        :param interval_type:
            The value to assign to the interval_type property of this JobScheduleDetails.
            Allowed values for this property are: "DAILY", "HOURLY", "WEEKLY", "MONTHLY", "NEVER", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type interval_type: str

        :param interval_value:
            The value to assign to the interval_value property of this JobScheduleDetails.
        :type interval_value: str

        """
        self.swagger_types = {
            'start_time': 'str',
            'end_time': 'str',
            'interval_type': 'str',
            'interval_value': 'str'
        }

        self.attribute_map = {
            'start_time': 'startTime',
            'end_time': 'endTime',
            'interval_type': 'intervalType',
            'interval_value': 'intervalValue'
        }

        self._start_time = None
        self._end_time = None
        self._interval_type = None
        self._interval_value = None

    @property
    def start_time(self):
        """
        Gets the start_time of this JobScheduleDetails.
        The start time of the scheduled job in UTC in ISO-8601 format, which is \"yyyy-MM-dd'T'hh:mm:ss.sss'Z'\".


        :return: The start_time of this JobScheduleDetails.
        :rtype: str
        """
        return self._start_time

    @start_time.setter
    def start_time(self, start_time):
        """
        Sets the start_time of this JobScheduleDetails.
        The start time of the scheduled job in UTC in ISO-8601 format, which is \"yyyy-MM-dd'T'hh:mm:ss.sss'Z'\".


        :param start_time: The start_time of this JobScheduleDetails.
        :type: str
        """
        self._start_time = start_time

    @property
    def end_time(self):
        """
        Gets the end_time of this JobScheduleDetails.
        The end time of the scheduled job in UTC in ISO-8601 format, which is \"yyyy-MM-dd'T'hh:mm:ss.sss'Z'\".


        :return: The end_time of this JobScheduleDetails.
        :rtype: str
        """
        return self._end_time

    @end_time.setter
    def end_time(self, end_time):
        """
        Sets the end_time of this JobScheduleDetails.
        The end time of the scheduled job in UTC in ISO-8601 format, which is \"yyyy-MM-dd'T'hh:mm:ss.sss'Z'\".


        :param end_time: The end_time of this JobScheduleDetails.
        :type: str
        """
        self._end_time = end_time

    @property
    def interval_type(self):
        """
        Gets the interval_type of this JobScheduleDetails.
        The interval type for a recurring scheduled job. For a non-recurring (one time) job, NEVER must be specified as the interval type.

        Allowed values for this property are: "DAILY", "HOURLY", "WEEKLY", "MONTHLY", "NEVER", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The interval_type of this JobScheduleDetails.
        :rtype: str
        """
        return self._interval_type

    @interval_type.setter
    def interval_type(self, interval_type):
        """
        Sets the interval_type of this JobScheduleDetails.
        The interval type for a recurring scheduled job. For a non-recurring (one time) job, NEVER must be specified as the interval type.


        :param interval_type: The interval_type of this JobScheduleDetails.
        :type: str
        """
        allowed_values = ["DAILY", "HOURLY", "WEEKLY", "MONTHLY", "NEVER"]
        if not value_allowed_none_or_none_sentinel(interval_type, allowed_values):
            interval_type = 'UNKNOWN_ENUM_VALUE'
        self._interval_type = interval_type

    @property
    def interval_value(self):
        """
        Gets the interval_value of this JobScheduleDetails.
        The value for the interval period for a recurring scheduled job.


        :return: The interval_value of this JobScheduleDetails.
        :rtype: str
        """
        return self._interval_value

    @interval_value.setter
    def interval_value(self, interval_value):
        """
        Sets the interval_value of this JobScheduleDetails.
        The value for the interval period for a recurring scheduled job.


        :param interval_value: The interval_value of this JobScheduleDetails.
        :type: str
        """
        self._interval_value = interval_value

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .data_source_details import DataSourceDetails
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class DataSourceDetailsATP(DataSourceDetails):
    """
    Data Source details for ATP
    """

    def __init__(self, **kwargs):
        """
        Initializes a new DataSourceDetailsATP object with values from keyword arguments. The default value of the :py:attr:`~oci.ai_anomaly_detection.models.DataSourceDetailsATP.data_source_type` attribute
        of this class is ``ORACLE_ATP`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param data_source_type:
            The value to assign to the data_source_type property of this DataSourceDetailsATP.
            Allowed values for this property are: "ORACLE_OBJECT_STORAGE", "ORACLE_ATP", "INFLUX"
        :type data_source_type: str

        :param wallet_password_secret_id:
            The value to assign to the wallet_password_secret_id property of this DataSourceDetailsATP.
        :type wallet_password_secret_id: str

        :param atp_user_name:
            The value to assign to the atp_user_name property of this DataSourceDetailsATP.
        :type atp_user_name: str

        :param atp_password_secret_id:
            The value to assign to the atp_password_secret_id property of this DataSourceDetailsATP.
        :type atp_password_secret_id: str

        :param cwallet_file_secret_id:
            The value to assign to the cwallet_file_secret_id property of this DataSourceDetailsATP.
        :type cwallet_file_secret_id: str

        :param ewallet_file_secret_id:
            The value to assign to the ewallet_file_secret_id property of this DataSourceDetailsATP.
        :type ewallet_file_secret_id: str

        :param key_store_file_secret_id:
            The value to assign to the key_store_file_secret_id property of this DataSourceDetailsATP.
        :type key_store_file_secret_id: str

        :param ojdbc_file_secret_id:
            The value to assign to the ojdbc_file_secret_id property of this DataSourceDetailsATP.
        :type ojdbc_file_secret_id: str

        :param tnsnames_file_secret_id:
            The value to assign to the tnsnames_file_secret_id property of this DataSourceDetailsATP.
        :type tnsnames_file_secret_id: str

        :param truststore_file_secret_id:
            The value to assign to the truststore_file_secret_id property of this DataSourceDetailsATP.
        :type truststore_file_secret_id: str

        :param database_name:
            The value to assign to the database_name property of this DataSourceDetailsATP.
        :type database_name: str

        :param table_name:
            The value to assign to the table_name property of this DataSourceDetailsATP.
        :type table_name: str

        """
        self.swagger_types = {
            'data_source_type': 'str',
            'wallet_password_secret_id': 'str',
            'atp_user_name': 'str',
            'atp_password_secret_id': 'str',
            'cwallet_file_secret_id': 'str',
            'ewallet_file_secret_id': 'str',
            'key_store_file_secret_id': 'str',
            'ojdbc_file_secret_id': 'str',
            'tnsnames_file_secret_id': 'str',
            'truststore_file_secret_id': 'str',
            'database_name': 'str',
            'table_name': 'str'
        }

        self.attribute_map = {
            'data_source_type': 'dataSourceType',
            'wallet_password_secret_id': 'walletPasswordSecretId',
            'atp_user_name': 'atpUserName',
            'atp_password_secret_id': 'atpPasswordSecretId',
            'cwallet_file_secret_id': 'cwalletFileSecretId',
            'ewallet_file_secret_id': 'ewalletFileSecretId',
            'key_store_file_secret_id': 'keyStoreFileSecretId',
            'ojdbc_file_secret_id': 'ojdbcFileSecretId',
            'tnsnames_file_secret_id': 'tnsnamesFileSecretId',
            'truststore_file_secret_id': 'truststoreFileSecretId',
            'database_name': 'databaseName',
            'table_name': 'tableName'
        }

        self._data_source_type = None
        self._wallet_password_secret_id = None
        self._atp_user_name = None
        self._atp_password_secret_id = None
        self._cwallet_file_secret_id = None
        self._ewallet_file_secret_id = None
        self._key_store_file_secret_id = None
        self._ojdbc_file_secret_id = None
        self._tnsnames_file_secret_id = None
        self._truststore_file_secret_id = None
        self._database_name = None
        self._table_name = None
        self._data_source_type = 'ORACLE_ATP'

    @property
    def wallet_password_secret_id(self):
        """
        Gets the wallet_password_secret_id of this DataSourceDetailsATP.
        wallet password Secret ID in String format


        :return: The wallet_password_secret_id of this DataSourceDetailsATP.
        :rtype: str
        """
        return self._wallet_password_secret_id

    @wallet_password_secret_id.setter
    def wallet_password_secret_id(self, wallet_password_secret_id):
        """
        Sets the wallet_password_secret_id of this DataSourceDetailsATP.
        wallet password Secret ID in String format


        :param wallet_password_secret_id: The wallet_password_secret_id of this DataSourceDetailsATP.
        :type: str
        """
        self._wallet_password_secret_id = wallet_password_secret_id

    @property
    def atp_user_name(self):
        """
        Gets the atp_user_name of this DataSourceDetailsATP.
        atp db user name


        :return: The atp_user_name of this DataSourceDetailsATP.
        :rtype: str
        """
        return self._atp_user_name

    @atp_user_name.setter
    def atp_user_name(self, atp_user_name):
        """
        Sets the atp_user_name of this DataSourceDetailsATP.
        atp db user name


        :param atp_user_name: The atp_user_name of this DataSourceDetailsATP.
        :type: str
        """
        self._atp_user_name = atp_user_name

    @property
    def atp_password_secret_id(self):
        """
        Gets the atp_password_secret_id of this DataSourceDetailsATP.
        atp db password Secret Id


        :return: The atp_password_secret_id of this DataSourceDetailsATP.
        :rtype: str
        """
        return self._atp_password_secret_id

    @atp_password_secret_id.setter
    def atp_password_secret_id(self, atp_password_secret_id):
        """
        Sets the atp_password_secret_id of this DataSourceDetailsATP.
        atp db password Secret Id


        :param atp_password_secret_id: The atp_password_secret_id of this DataSourceDetailsATP.
        :type: str
        """
        self._atp_password_secret_id = atp_password_secret_id

    @property
    def cwallet_file_secret_id(self):
        """
        Gets the cwallet_file_secret_id of this DataSourceDetailsATP.
        OCID of the secret containing the containers certificates of ATP wallet


        :return: The cwallet_file_secret_id of this DataSourceDetailsATP.
        :rtype: str
        """
        return self._cwallet_file_secret_id

    @cwallet_file_secret_id.setter
    def cwallet_file_secret_id(self, cwallet_file_secret_id):
        """
        Sets the cwallet_file_secret_id of this DataSourceDetailsATP.
        OCID of the secret containing the containers certificates of ATP wallet


        :param cwallet_file_secret_id: The cwallet_file_secret_id of this DataSourceDetailsATP.
        :type: str
        """
        self._cwallet_file_secret_id = cwallet_file_secret_id

    @property
    def ewallet_file_secret_id(self):
        """
        Gets the ewallet_file_secret_id of this DataSourceDetailsATP.
        OCID of the secret containing the PDB'S certificates of ATP wallet


        :return: The ewallet_file_secret_id of this DataSourceDetailsATP.
        :rtype: str
        """
        return self._ewallet_file_secret_id

    @ewallet_file_secret_id.setter
    def ewallet_file_secret_id(self, ewallet_file_secret_id):
        """
        Sets the ewallet_file_secret_id of this DataSourceDetailsATP.
        OCID of the secret containing the PDB'S certificates of ATP wallet


        :param ewallet_file_secret_id: The ewallet_file_secret_id of this DataSourceDetailsATP.
        :type: str
        """
        self._ewallet_file_secret_id = ewallet_file_secret_id

    @property
    def key_store_file_secret_id(self):
        """
        Gets the key_store_file_secret_id of this DataSourceDetailsATP.
        OCID of the secret containing Keystore.jks file of the ATP wallet


        :return: The key_store_file_secret_id of this DataSourceDetailsATP.
        :rtype: str
        """
        return self._key_store_file_secret_id

    @key_store_file_secret_id.setter
    def key_store_file_secret_id(self, key_store_file_secret_id):
        """
        Sets the key_store_file_secret_id of this DataSourceDetailsATP.
        OCID of the secret containing Keystore.jks file of the ATP wallet


        :param key_store_file_secret_id: The key_store_file_secret_id of this DataSourceDetailsATP.
        :type: str
        """
        self._key_store_file_secret_id = key_store_file_secret_id

    @property
    def ojdbc_file_secret_id(self):
        """
        Gets the ojdbc_file_secret_id of this DataSourceDetailsATP.
        OCID of the secret that contains jdbc properties file of ATP wallet


        :return: The ojdbc_file_secret_id of this DataSourceDetailsATP.
        :rtype: str
        """
        return self._ojdbc_file_secret_id

    @ojdbc_file_secret_id.setter
    def ojdbc_file_secret_id(self, ojdbc_file_secret_id):
        """
        Sets the ojdbc_file_secret_id of this DataSourceDetailsATP.
        OCID of the secret that contains jdbc properties file of ATP wallet


        :param ojdbc_file_secret_id: The ojdbc_file_secret_id of this DataSourceDetailsATP.
        :type: str
        """
        self._ojdbc_file_secret_id = ojdbc_file_secret_id

    @property
    def tnsnames_file_secret_id(self):
        """
        Gets the tnsnames_file_secret_id of this DataSourceDetailsATP.
        OCID of the secret that contains the tnsnames file of ATP wallet


        :return: The tnsnames_file_secret_id of this DataSourceDetailsATP.
        :rtype: str
        """
        return self._tnsnames_file_secret_id

    @tnsnames_file_secret_id.setter
    def tnsnames_file_secret_id(self, tnsnames_file_secret_id):
        """
        Sets the tnsnames_file_secret_id of this DataSourceDetailsATP.
        OCID of the secret that contains the tnsnames file of ATP wallet


        :param tnsnames_file_secret_id: The tnsnames_file_secret_id of this DataSourceDetailsATP.
        :type: str
        """
        self._tnsnames_file_secret_id = tnsnames_file_secret_id

    @property
    def truststore_file_secret_id(self):
        """
        Gets the truststore_file_secret_id of this DataSourceDetailsATP.
        OCID of the secret containing truststore.jks file of the ATP wallet


        :return: The truststore_file_secret_id of this DataSourceDetailsATP.
        :rtype: str
        """
        return self._truststore_file_secret_id

    @truststore_file_secret_id.setter
    def truststore_file_secret_id(self, truststore_file_secret_id):
        """
        Sets the truststore_file_secret_id of this DataSourceDetailsATP.
        OCID of the secret containing truststore.jks file of the ATP wallet


        :param truststore_file_secret_id: The truststore_file_secret_id of this DataSourceDetailsATP.
        :type: str
        """
        self._truststore_file_secret_id = truststore_file_secret_id

    @property
    def database_name(self):
        """
        Gets the database_name of this DataSourceDetailsATP.
        atp database name


        :return: The database_name of this DataSourceDetailsATP.
        :rtype: str
        """
        return self._database_name

    @database_name.setter
    def database_name(self, database_name):
        """
        Sets the database_name of this DataSourceDetailsATP.
        atp database name


        :param database_name: The database_name of this DataSourceDetailsATP.
        :type: str
        """
        self._database_name = database_name

    @property
    def table_name(self):
        """
        Gets the table_name of this DataSourceDetailsATP.
        atp database table name


        :return: The table_name of this DataSourceDetailsATP.
        :rtype: str
        """
        return self._table_name

    @table_name.setter
    def table_name(self, table_name):
        """
        Sets the table_name of this DataSourceDetailsATP.
        atp database table name


        :param table_name: The table_name of this DataSourceDetailsATP.
        :type: str
        """
        self._table_name = table_name

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class UpdateCloudExadataInfrastructureDetails(object):
    """
    Updates the cloud Exadata infrastructure. Applies to Exadata Cloud Service instances only.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new UpdateCloudExadataInfrastructureDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param display_name:
            The value to assign to the display_name property of this UpdateCloudExadataInfrastructureDetails.
        :type display_name: str

        :param maintenance_window:
            The value to assign to the maintenance_window property of this UpdateCloudExadataInfrastructureDetails.
        :type maintenance_window: oci.database.models.MaintenanceWindow

        :param compute_count:
            The value to assign to the compute_count property of this UpdateCloudExadataInfrastructureDetails.
        :type compute_count: int

        :param storage_count:
            The value to assign to the storage_count property of this UpdateCloudExadataInfrastructureDetails.
        :type storage_count: int

        :param freeform_tags:
            The value to assign to the freeform_tags property of this UpdateCloudExadataInfrastructureDetails.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this UpdateCloudExadataInfrastructureDetails.
        :type defined_tags: dict(str, dict(str, object))

        :param customer_contacts:
            The value to assign to the customer_contacts property of this UpdateCloudExadataInfrastructureDetails.
        :type customer_contacts: list[oci.database.models.CustomerContact]

        """
        self.swagger_types = {
            'display_name': 'str',
            'maintenance_window': 'MaintenanceWindow',
            'compute_count': 'int',
            'storage_count': 'int',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))',
            'customer_contacts': 'list[CustomerContact]'
        }

        self.attribute_map = {
            'display_name': 'displayName',
            'maintenance_window': 'maintenanceWindow',
            'compute_count': 'computeCount',
            'storage_count': 'storageCount',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags',
            'customer_contacts': 'customerContacts'
        }

        self._display_name = None
        self._maintenance_window = None
        self._compute_count = None
        self._storage_count = None
        self._freeform_tags = None
        self._defined_tags = None
        self._customer_contacts = None

    @property
    def display_name(self):
        """
        Gets the display_name of this UpdateCloudExadataInfrastructureDetails.
        The user-friendly name for the cloud Exadata infrastructure. The name does not need to be unique.


        :return: The display_name of this UpdateCloudExadataInfrastructureDetails.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this UpdateCloudExadataInfrastructureDetails.
        The user-friendly name for the cloud Exadata infrastructure. The name does not need to be unique.


        :param display_name: The display_name of this UpdateCloudExadataInfrastructureDetails.
        :type: str
        """
        self._display_name = display_name

    @property
    def maintenance_window(self):
        """
        Gets the maintenance_window of this UpdateCloudExadataInfrastructureDetails.

        :return: The maintenance_window of this UpdateCloudExadataInfrastructureDetails.
        :rtype: oci.database.models.MaintenanceWindow
        """
        return self._maintenance_window

    @maintenance_window.setter
    def maintenance_window(self, maintenance_window):
        """
        Sets the maintenance_window of this UpdateCloudExadataInfrastructureDetails.

        :param maintenance_window: The maintenance_window of this UpdateCloudExadataInfrastructureDetails.
        :type: oci.database.models.MaintenanceWindow
        """
        self._maintenance_window = maintenance_window

    @property
    def compute_count(self):
        """
        Gets the compute_count of this UpdateCloudExadataInfrastructureDetails.
        The number of compute servers for the cloud Exadata infrastructure.


        :return: The compute_count of this UpdateCloudExadataInfrastructureDetails.
        :rtype: int
        """
        return self._compute_count

    @compute_count.setter
    def compute_count(self, compute_count):
        """
        Sets the compute_count of this UpdateCloudExadataInfrastructureDetails.
        The number of compute servers for the cloud Exadata infrastructure.


        :param compute_count: The compute_count of this UpdateCloudExadataInfrastructureDetails.
        :type: int
        """
        self._compute_count = compute_count

    @property
    def storage_count(self):
        """
        Gets the storage_count of this UpdateCloudExadataInfrastructureDetails.
        The number of storage servers for the cloud Exadata infrastructure.


        :return: The storage_count of this UpdateCloudExadataInfrastructureDetails.
        :rtype: int
        """
        return self._storage_count

    @storage_count.setter
    def storage_count(self, storage_count):
        """
        Sets the storage_count of this UpdateCloudExadataInfrastructureDetails.
        The number of storage servers for the cloud Exadata infrastructure.


        :param storage_count: The storage_count of this UpdateCloudExadataInfrastructureDetails.
        :type: int
        """
        self._storage_count = storage_count

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this UpdateCloudExadataInfrastructureDetails.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace.
        For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The freeform_tags of this UpdateCloudExadataInfrastructureDetails.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this UpdateCloudExadataInfrastructureDetails.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace.
        For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param freeform_tags: The freeform_tags of this UpdateCloudExadataInfrastructureDetails.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this UpdateCloudExadataInfrastructureDetails.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        For more information, see `Resource Tags`__.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The defined_tags of this UpdateCloudExadataInfrastructureDetails.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this UpdateCloudExadataInfrastructureDetails.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        For more information, see `Resource Tags`__.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param defined_tags: The defined_tags of this UpdateCloudExadataInfrastructureDetails.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    @property
    def customer_contacts(self):
        """
        Gets the customer_contacts of this UpdateCloudExadataInfrastructureDetails.
        Customer contacts. Setting this to an empty list removes all customer contact information (email addresses) for the specified OCI Database service resource.


        :return: The customer_contacts of this UpdateCloudExadataInfrastructureDetails.
        :rtype: list[oci.database.models.CustomerContact]
        """
        return self._customer_contacts

    @customer_contacts.setter
    def customer_contacts(self, customer_contacts):
        """
        Sets the customer_contacts of this UpdateCloudExadataInfrastructureDetails.
        Customer contacts. Setting this to an empty list removes all customer contact information (email addresses) for the specified OCI Database service resource.


        :param customer_contacts: The customer_contacts of this UpdateCloudExadataInfrastructureDetails.
        :type: list[oci.database.models.CustomerContact]
        """
        self._customer_contacts = customer_contacts

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class DbSystemSummary(object):
    """
    A summary of a DB System.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new DbSystemSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this DbSystemSummary.
        :type id: str

        :param display_name:
            The value to assign to the display_name property of this DbSystemSummary.
        :type display_name: str

        :param description:
            The value to assign to the description property of this DbSystemSummary.
        :type description: str

        :param compartment_id:
            The value to assign to the compartment_id property of this DbSystemSummary.
        :type compartment_id: str

        :param is_highly_available:
            The value to assign to the is_highly_available property of this DbSystemSummary.
        :type is_highly_available: bool

        :param current_placement:
            The value to assign to the current_placement property of this DbSystemSummary.
        :type current_placement: oci.mysql.models.DbSystemPlacement

        :param is_analytics_cluster_attached:
            The value to assign to the is_analytics_cluster_attached property of this DbSystemSummary.
        :type is_analytics_cluster_attached: bool

        :param analytics_cluster:
            The value to assign to the analytics_cluster property of this DbSystemSummary.
        :type analytics_cluster: oci.mysql.models.AnalyticsClusterSummary

        :param is_heat_wave_cluster_attached:
            The value to assign to the is_heat_wave_cluster_attached property of this DbSystemSummary.
        :type is_heat_wave_cluster_attached: bool

        :param heat_wave_cluster:
            The value to assign to the heat_wave_cluster property of this DbSystemSummary.
        :type heat_wave_cluster: oci.mysql.models.HeatWaveClusterSummary

        :param availability_domain:
            The value to assign to the availability_domain property of this DbSystemSummary.
        :type availability_domain: str

        :param fault_domain:
            The value to assign to the fault_domain property of this DbSystemSummary.
        :type fault_domain: str

        :param endpoints:
            The value to assign to the endpoints property of this DbSystemSummary.
        :type endpoints: list[oci.mysql.models.DbSystemEndpoint]

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this DbSystemSummary.
        :type lifecycle_state: str

        :param mysql_version:
            The value to assign to the mysql_version property of this DbSystemSummary.
        :type mysql_version: str

        :param time_created:
            The value to assign to the time_created property of this DbSystemSummary.
        :type time_created: datetime

        :param time_updated:
            The value to assign to the time_updated property of this DbSystemSummary.
        :type time_updated: datetime

        :param freeform_tags:
            The value to assign to the freeform_tags property of this DbSystemSummary.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this DbSystemSummary.
        :type defined_tags: dict(str, dict(str, object))

        """
        self.swagger_types = {
            'id': 'str',
            'display_name': 'str',
            'description': 'str',
            'compartment_id': 'str',
            'is_highly_available': 'bool',
            'current_placement': 'DbSystemPlacement',
            'is_analytics_cluster_attached': 'bool',
            'analytics_cluster': 'AnalyticsClusterSummary',
            'is_heat_wave_cluster_attached': 'bool',
            'heat_wave_cluster': 'HeatWaveClusterSummary',
            'availability_domain': 'str',
            'fault_domain': 'str',
            'endpoints': 'list[DbSystemEndpoint]',
            'lifecycle_state': 'str',
            'mysql_version': 'str',
            'time_created': 'datetime',
            'time_updated': 'datetime',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))'
        }

        self.attribute_map = {
            'id': 'id',
            'display_name': 'displayName',
            'description': 'description',
            'compartment_id': 'compartmentId',
            'is_highly_available': 'isHighlyAvailable',
            'current_placement': 'currentPlacement',
            'is_analytics_cluster_attached': 'isAnalyticsClusterAttached',
            'analytics_cluster': 'analyticsCluster',
            'is_heat_wave_cluster_attached': 'isHeatWaveClusterAttached',
            'heat_wave_cluster': 'heatWaveCluster',
            'availability_domain': 'availabilityDomain',
            'fault_domain': 'faultDomain',
            'endpoints': 'endpoints',
            'lifecycle_state': 'lifecycleState',
            'mysql_version': 'mysqlVersion',
            'time_created': 'timeCreated',
            'time_updated': 'timeUpdated',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags'
        }

        self._id = None
        self._display_name = None
        self._description = None
        self._compartment_id = None
        self._is_highly_available = None
        self._current_placement = None
        self._is_analytics_cluster_attached = None
        self._analytics_cluster = None
        self._is_heat_wave_cluster_attached = None
        self._heat_wave_cluster = None
        self._availability_domain = None
        self._fault_domain = None
        self._endpoints = None
        self._lifecycle_state = None
        self._mysql_version = None
        self._time_created = None
        self._time_updated = None
        self._freeform_tags = None
        self._defined_tags = None

    @property
    def id(self):
        """
        **[Required]** Gets the id of this DbSystemSummary.
        The OCID of the DB System.


        :return: The id of this DbSystemSummary.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this DbSystemSummary.
        The OCID of the DB System.


        :param id: The id of this DbSystemSummary.
        :type: str
        """
        self._id = id

    @property
    def display_name(self):
        """
        **[Required]** Gets the display_name of this DbSystemSummary.
        The user-friendly name for the DB System. It does not have to be unique.


        :return: The display_name of this DbSystemSummary.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this DbSystemSummary.
        The user-friendly name for the DB System. It does not have to be unique.


        :param display_name: The display_name of this DbSystemSummary.
        :type: str
        """
        self._display_name = display_name

    @property
    def description(self):
        """
        Gets the description of this DbSystemSummary.
        User-provided data about the DB System.


        :return: The description of this DbSystemSummary.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this DbSystemSummary.
        User-provided data about the DB System.


        :param description: The description of this DbSystemSummary.
        :type: str
        """
        self._description = description

    @property
    def compartment_id(self):
        """
        Gets the compartment_id of this DbSystemSummary.
        The OCID of the compartment the DB System belongs in.


        :return: The compartment_id of this DbSystemSummary.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this DbSystemSummary.
        The OCID of the compartment the DB System belongs in.


        :param compartment_id: The compartment_id of this DbSystemSummary.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def is_highly_available(self):
        """
        Gets the is_highly_available of this DbSystemSummary.
        If the policy is to enable high availability of the instance, by
        maintaining secondary/failover capacity as necessary.


        :return: The is_highly_available of this DbSystemSummary.
        :rtype: bool
        """
        return self._is_highly_available

    @is_highly_available.setter
    def is_highly_available(self, is_highly_available):
        """
        Sets the is_highly_available of this DbSystemSummary.
        If the policy is to enable high availability of the instance, by
        maintaining secondary/failover capacity as necessary.


        :param is_highly_available: The is_highly_available of this DbSystemSummary.
        :type: bool
        """
        self._is_highly_available = is_highly_available

    @property
    def current_placement(self):
        """
        Gets the current_placement of this DbSystemSummary.

        :return: The current_placement of this DbSystemSummary.
        :rtype: oci.mysql.models.DbSystemPlacement
        """
        return self._current_placement

    @current_placement.setter
    def current_placement(self, current_placement):
        """
        Sets the current_placement of this DbSystemSummary.

        :param current_placement: The current_placement of this DbSystemSummary.
        :type: oci.mysql.models.DbSystemPlacement
        """
        self._current_placement = current_placement

    @property
    def is_analytics_cluster_attached(self):
        """
        Gets the is_analytics_cluster_attached of this DbSystemSummary.
        DEPRECATED -- please use `isHeatWaveClusterAttached` instead.
        If the DB System has an Analytics Cluster attached.


        :return: The is_analytics_cluster_attached of this DbSystemSummary.
        :rtype: bool
        """
        return self._is_analytics_cluster_attached

    @is_analytics_cluster_attached.setter
    def is_analytics_cluster_attached(self, is_analytics_cluster_attached):
        """
        Sets the is_analytics_cluster_attached of this DbSystemSummary.
        DEPRECATED -- please use `isHeatWaveClusterAttached` instead.
        If the DB System has an Analytics Cluster attached.


        :param is_analytics_cluster_attached: The is_analytics_cluster_attached of this DbSystemSummary.
        :type: bool
        """
        self._is_analytics_cluster_attached = is_analytics_cluster_attached

    @property
    def analytics_cluster(self):
        """
        Gets the analytics_cluster of this DbSystemSummary.

        :return: The analytics_cluster of this DbSystemSummary.
        :rtype: oci.mysql.models.AnalyticsClusterSummary
        """
        return self._analytics_cluster

    @analytics_cluster.setter
    def analytics_cluster(self, analytics_cluster):
        """
        Sets the analytics_cluster of this DbSystemSummary.

        :param analytics_cluster: The analytics_cluster of this DbSystemSummary.
        :type: oci.mysql.models.AnalyticsClusterSummary
        """
        self._analytics_cluster = analytics_cluster

    @property
    def is_heat_wave_cluster_attached(self):
        """
        Gets the is_heat_wave_cluster_attached of this DbSystemSummary.
        If the DB System has a HeatWave Cluster attached.


        :return: The is_heat_wave_cluster_attached of this DbSystemSummary.
        :rtype: bool
        """
        return self._is_heat_wave_cluster_attached

    @is_heat_wave_cluster_attached.setter
    def is_heat_wave_cluster_attached(self, is_heat_wave_cluster_attached):
        """
        Sets the is_heat_wave_cluster_attached of this DbSystemSummary.
        If the DB System has a HeatWave Cluster attached.


        :param is_heat_wave_cluster_attached: The is_heat_wave_cluster_attached of this DbSystemSummary.
        :type: bool
        """
        self._is_heat_wave_cluster_attached = is_heat_wave_cluster_attached

    @property
    def heat_wave_cluster(self):
        """
        Gets the heat_wave_cluster of this DbSystemSummary.

        :return: The heat_wave_cluster of this DbSystemSummary.
        :rtype: oci.mysql.models.HeatWaveClusterSummary
        """
        return self._heat_wave_cluster

    @heat_wave_cluster.setter
    def heat_wave_cluster(self, heat_wave_cluster):
        """
        Sets the heat_wave_cluster of this DbSystemSummary.

        :param heat_wave_cluster: The heat_wave_cluster of this DbSystemSummary.
        :type: oci.mysql.models.HeatWaveClusterSummary
        """
        self._heat_wave_cluster = heat_wave_cluster

    @property
    def availability_domain(self):
        """
        Gets the availability_domain of this DbSystemSummary.
        The availability domain on which to deploy the Read/Write endpoint. This defines the preferred primary instance.

        In a failover scenario, the Read/Write endpoint is redirected to one of the other availability domains
        and the MySQL instance in that domain is promoted to the primary instance.
        This redirection does not affect the IP address of the DB System in any way.

        For a standalone DB System, this defines the availability domain in which the DB System is placed.


        :return: The availability_domain of this DbSystemSummary.
        :rtype: str
        """
        return self._availability_domain

    @availability_domain.setter
    def availability_domain(self, availability_domain):
        """
        Sets the availability_domain of this DbSystemSummary.
        The availability domain on which to deploy the Read/Write endpoint. This defines the preferred primary instance.

        In a failover scenario, the Read/Write endpoint is redirected to one of the other availability domains
        and the MySQL instance in that domain is promoted to the primary instance.
        This redirection does not affect the IP address of the DB System in any way.

        For a standalone DB System, this defines the availability domain in which the DB System is placed.


        :param availability_domain: The availability_domain of this DbSystemSummary.
        :type: str
        """
        self._availability_domain = availability_domain

    @property
    def fault_domain(self):
        """
        Gets the fault_domain of this DbSystemSummary.
        The fault domain on which to deploy the Read/Write endpoint. This defines the preferred primary instance.

        In a failover scenario, the Read/Write endpoint is redirected to one of the other fault domains
        and the MySQL instance in that domain is promoted to the primary instance.
        This redirection does not affect the IP address of the DB System in any way.

        For a standalone DB System, this defines the fault domain in which the DB System is placed.


        :return: The fault_domain of this DbSystemSummary.
        :rtype: str
        """
        return self._fault_domain

    @fault_domain.setter
    def fault_domain(self, fault_domain):
        """
        Sets the fault_domain of this DbSystemSummary.
        The fault domain on which to deploy the Read/Write endpoint. This defines the preferred primary instance.

        In a failover scenario, the Read/Write endpoint is redirected to one of the other fault domains
        and the MySQL instance in that domain is promoted to the primary instance.
        This redirection does not affect the IP address of the DB System in any way.

        For a standalone DB System, this defines the fault domain in which the DB System is placed.


        :param fault_domain: The fault_domain of this DbSystemSummary.
        :type: str
        """
        self._fault_domain = fault_domain

    @property
    def endpoints(self):
        """
        Gets the endpoints of this DbSystemSummary.
        The network endpoints available for this DB System.


        :return: The endpoints of this DbSystemSummary.
        :rtype: list[oci.mysql.models.DbSystemEndpoint]
        """
        return self._endpoints

    @endpoints.setter
    def endpoints(self, endpoints):
        """
        Sets the endpoints of this DbSystemSummary.
        The network endpoints available for this DB System.


        :param endpoints: The endpoints of this DbSystemSummary.
        :type: list[oci.mysql.models.DbSystemEndpoint]
        """
        self._endpoints = endpoints

    @property
    def lifecycle_state(self):
        """
        **[Required]** Gets the lifecycle_state of this DbSystemSummary.
        The current state of the DB System.


        :return: The lifecycle_state of this DbSystemSummary.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this DbSystemSummary.
        The current state of the DB System.


        :param lifecycle_state: The lifecycle_state of this DbSystemSummary.
        :type: str
        """
        self._lifecycle_state = lifecycle_state

    @property
    def mysql_version(self):
        """
        **[Required]** Gets the mysql_version of this DbSystemSummary.
        Name of the MySQL Version in use for the DB System.


        :return: The mysql_version of this DbSystemSummary.
        :rtype: str
        """
        return self._mysql_version

    @mysql_version.setter
    def mysql_version(self, mysql_version):
        """
        Sets the mysql_version of this DbSystemSummary.
        Name of the MySQL Version in use for the DB System.


        :param mysql_version: The mysql_version of this DbSystemSummary.
        :type: str
        """
        self._mysql_version = mysql_version

    @property
    def time_created(self):
        """
        **[Required]** Gets the time_created of this DbSystemSummary.
        The date and time the DB System was created.


        :return: The time_created of this DbSystemSummary.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this DbSystemSummary.
        The date and time the DB System was created.


        :param time_created: The time_created of this DbSystemSummary.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def time_updated(self):
        """
        **[Required]** Gets the time_updated of this DbSystemSummary.
        The time the DB System was last updated.


        :return: The time_updated of this DbSystemSummary.
        :rtype: datetime
        """
        return self._time_updated

    @time_updated.setter
    def time_updated(self, time_updated):
        """
        Sets the time_updated of this DbSystemSummary.
        The time the DB System was last updated.


        :param time_updated: The time_updated of this DbSystemSummary.
        :type: datetime
        """
        self._time_updated = time_updated

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this DbSystemSummary.
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
        Example: `{\"bar-key\": \"value\"}`


        :return: The freeform_tags of this DbSystemSummary.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this DbSystemSummary.
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
        Example: `{\"bar-key\": \"value\"}`


        :param freeform_tags: The freeform_tags of this DbSystemSummary.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this DbSystemSummary.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :return: The defined_tags of this DbSystemSummary.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this DbSystemSummary.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :param defined_tags: The defined_tags of this DbSystemSummary.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ScheduledTaskSummary(object):
    """
    Summary information about a scheduled task.
    """

    #: A constant which can be used with the task_type property of a ScheduledTaskSummary.
    #: This constant has a value of "SAVED_SEARCH"
    TASK_TYPE_SAVED_SEARCH = "SAVED_SEARCH"

    #: A constant which can be used with the task_type property of a ScheduledTaskSummary.
    #: This constant has a value of "ACCELERATION"
    TASK_TYPE_ACCELERATION = "ACCELERATION"

    #: A constant which can be used with the task_type property of a ScheduledTaskSummary.
    #: This constant has a value of "PURGE"
    TASK_TYPE_PURGE = "PURGE"

    #: A constant which can be used with the task_type property of a ScheduledTaskSummary.
    #: This constant has a value of "ACCELERATION_MAINTENANCE"
    TASK_TYPE_ACCELERATION_MAINTENANCE = "ACCELERATION_MAINTENANCE"

    #: A constant which can be used with the task_status property of a ScheduledTaskSummary.
    #: This constant has a value of "READY"
    TASK_STATUS_READY = "READY"

    #: A constant which can be used with the task_status property of a ScheduledTaskSummary.
    #: This constant has a value of "PAUSED"
    TASK_STATUS_PAUSED = "PAUSED"

    #: A constant which can be used with the task_status property of a ScheduledTaskSummary.
    #: This constant has a value of "COMPLETED"
    TASK_STATUS_COMPLETED = "COMPLETED"

    #: A constant which can be used with the task_status property of a ScheduledTaskSummary.
    #: This constant has a value of "BLOCKED"
    TASK_STATUS_BLOCKED = "BLOCKED"

    #: A constant which can be used with the last_execution_status property of a ScheduledTaskSummary.
    #: This constant has a value of "FAILED"
    LAST_EXECUTION_STATUS_FAILED = "FAILED"

    #: A constant which can be used with the last_execution_status property of a ScheduledTaskSummary.
    #: This constant has a value of "SUCCEEDED"
    LAST_EXECUTION_STATUS_SUCCEEDED = "SUCCEEDED"

    def __init__(self, **kwargs):
        """
        Initializes a new ScheduledTaskSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this ScheduledTaskSummary.
        :type id: str

        :param task_type:
            The value to assign to the task_type property of this ScheduledTaskSummary.
            Allowed values for this property are: "SAVED_SEARCH", "ACCELERATION", "PURGE", "ACCELERATION_MAINTENANCE", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type task_type: str

        :param compartment_id:
            The value to assign to the compartment_id property of this ScheduledTaskSummary.
        :type compartment_id: str

        :param time_created:
            The value to assign to the time_created property of this ScheduledTaskSummary.
        :type time_created: datetime

        :param time_updated:
            The value to assign to the time_updated property of this ScheduledTaskSummary.
        :type time_updated: datetime

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this ScheduledTaskSummary.
        :type lifecycle_state: str

        :param task_status:
            The value to assign to the task_status property of this ScheduledTaskSummary.
            Allowed values for this property are: "READY", "PAUSED", "COMPLETED", "BLOCKED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type task_status: str

        :param pause_reason:
            The value to assign to the pause_reason property of this ScheduledTaskSummary.
        :type pause_reason: str

        :param work_request_id:
            The value to assign to the work_request_id property of this ScheduledTaskSummary.
        :type work_request_id: str

        :param display_name:
            The value to assign to the display_name property of this ScheduledTaskSummary.
        :type display_name: str

        :param freeform_tags:
            The value to assign to the freeform_tags property of this ScheduledTaskSummary.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this ScheduledTaskSummary.
        :type defined_tags: dict(str, dict(str, object))

        :param last_execution_status:
            The value to assign to the last_execution_status property of this ScheduledTaskSummary.
            Allowed values for this property are: "FAILED", "SUCCEEDED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type last_execution_status: str

        :param time_last_executed:
            The value to assign to the time_last_executed property of this ScheduledTaskSummary.
        :type time_last_executed: datetime

        """
        self.swagger_types = {
            'id': 'str',
            'task_type': 'str',
            'compartment_id': 'str',
            'time_created': 'datetime',
            'time_updated': 'datetime',
            'lifecycle_state': 'str',
            'task_status': 'str',
            'pause_reason': 'str',
            'work_request_id': 'str',
            'display_name': 'str',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))',
            'last_execution_status': 'str',
            'time_last_executed': 'datetime'
        }

        self.attribute_map = {
            'id': 'id',
            'task_type': 'taskType',
            'compartment_id': 'compartmentId',
            'time_created': 'timeCreated',
            'time_updated': 'timeUpdated',
            'lifecycle_state': 'lifecycleState',
            'task_status': 'taskStatus',
            'pause_reason': 'pauseReason',
            'work_request_id': 'workRequestId',
            'display_name': 'displayName',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags',
            'last_execution_status': 'lastExecutionStatus',
            'time_last_executed': 'timeLastExecuted'
        }

        self._id = None
        self._task_type = None
        self._compartment_id = None
        self._time_created = None
        self._time_updated = None
        self._lifecycle_state = None
        self._task_status = None
        self._pause_reason = None
        self._work_request_id = None
        self._display_name = None
        self._freeform_tags = None
        self._defined_tags = None
        self._last_execution_status = None
        self._time_last_executed = None

    @property
    def id(self):
        """
        **[Required]** Gets the id of this ScheduledTaskSummary.
        The `OCID`__ of the data plane resource.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The id of this ScheduledTaskSummary.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this ScheduledTaskSummary.
        The `OCID`__ of the data plane resource.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param id: The id of this ScheduledTaskSummary.
        :type: str
        """
        self._id = id

    @property
    def task_type(self):
        """
        **[Required]** Gets the task_type of this ScheduledTaskSummary.
        Task type.

        Allowed values for this property are: "SAVED_SEARCH", "ACCELERATION", "PURGE", "ACCELERATION_MAINTENANCE", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The task_type of this ScheduledTaskSummary.
        :rtype: str
        """
        return self._task_type

    @task_type.setter
    def task_type(self, task_type):
        """
        Sets the task_type of this ScheduledTaskSummary.
        Task type.


        :param task_type: The task_type of this ScheduledTaskSummary.
        :type: str
        """
        allowed_values = ["SAVED_SEARCH", "ACCELERATION", "PURGE", "ACCELERATION_MAINTENANCE"]
        if not value_allowed_none_or_none_sentinel(task_type, allowed_values):
            task_type = 'UNKNOWN_ENUM_VALUE'
        self._task_type = task_type

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this ScheduledTaskSummary.
        Compartment Identifier `OCID]`__.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The compartment_id of this ScheduledTaskSummary.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this ScheduledTaskSummary.
        Compartment Identifier `OCID]`__.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param compartment_id: The compartment_id of this ScheduledTaskSummary.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def time_created(self):
        """
        **[Required]** Gets the time_created of this ScheduledTaskSummary.
        The date and time the schedule task was created, in the format defined by RFC3339.


        :return: The time_created of this ScheduledTaskSummary.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this ScheduledTaskSummary.
        The date and time the schedule task was created, in the format defined by RFC3339.


        :param time_created: The time_created of this ScheduledTaskSummary.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def time_updated(self):
        """
        **[Required]** Gets the time_updated of this ScheduledTaskSummary.
        The date and time the scheduled task was last updated, in the format defined by RFC3339.


        :return: The time_updated of this ScheduledTaskSummary.
        :rtype: datetime
        """
        return self._time_updated

    @time_updated.setter
    def time_updated(self, time_updated):
        """
        Sets the time_updated of this ScheduledTaskSummary.
        The date and time the scheduled task was last updated, in the format defined by RFC3339.


        :param time_updated: The time_updated of this ScheduledTaskSummary.
        :type: datetime
        """
        self._time_updated = time_updated

    @property
    def lifecycle_state(self):
        """
        **[Required]** Gets the lifecycle_state of this ScheduledTaskSummary.
        The current state of the scheduled task.


        :return: The lifecycle_state of this ScheduledTaskSummary.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this ScheduledTaskSummary.
        The current state of the scheduled task.


        :param lifecycle_state: The lifecycle_state of this ScheduledTaskSummary.
        :type: str
        """
        self._lifecycle_state = lifecycle_state

    @property
    def task_status(self):
        """
        Gets the task_status of this ScheduledTaskSummary.
        Status of the scheduled task.

        Allowed values for this property are: "READY", "PAUSED", "COMPLETED", "BLOCKED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The task_status of this ScheduledTaskSummary.
        :rtype: str
        """
        return self._task_status

    @task_status.setter
    def task_status(self, task_status):
        """
        Sets the task_status of this ScheduledTaskSummary.
        Status of the scheduled task.


        :param task_status: The task_status of this ScheduledTaskSummary.
        :type: str
        """
        allowed_values = ["READY", "PAUSED", "COMPLETED", "BLOCKED"]
        if not value_allowed_none_or_none_sentinel(task_status, allowed_values):
            task_status = 'UNKNOWN_ENUM_VALUE'
        self._task_status = task_status

    @property
    def pause_reason(self):
        """
        Gets the pause_reason of this ScheduledTaskSummary.
        reason for taskStatus PAUSED.


        :return: The pause_reason of this ScheduledTaskSummary.
        :rtype: str
        """
        return self._pause_reason

    @pause_reason.setter
    def pause_reason(self, pause_reason):
        """
        Sets the pause_reason of this ScheduledTaskSummary.
        reason for taskStatus PAUSED.


        :param pause_reason: The pause_reason of this ScheduledTaskSummary.
        :type: str
        """
        self._pause_reason = pause_reason

    @property
    def work_request_id(self):
        """
        Gets the work_request_id of this ScheduledTaskSummary.
        most recent Work Request Identifier `OCID]`__ for the asynchronous request.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The work_request_id of this ScheduledTaskSummary.
        :rtype: str
        """
        return self._work_request_id

    @work_request_id.setter
    def work_request_id(self, work_request_id):
        """
        Sets the work_request_id of this ScheduledTaskSummary.
        most recent Work Request Identifier `OCID]`__ for the asynchronous request.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param work_request_id: The work_request_id of this ScheduledTaskSummary.
        :type: str
        """
        self._work_request_id = work_request_id

    @property
    def display_name(self):
        """
        **[Required]** Gets the display_name of this ScheduledTaskSummary.
        A user-friendly name that is changeable and that does not have to be unique.
        Format: a leading alphanumeric, followed by zero or more
        alphanumerics, underscores, spaces, backslashes, or hyphens in any order).
        No trailing spaces allowed.


        :return: The display_name of this ScheduledTaskSummary.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this ScheduledTaskSummary.
        A user-friendly name that is changeable and that does not have to be unique.
        Format: a leading alphanumeric, followed by zero or more
        alphanumerics, underscores, spaces, backslashes, or hyphens in any order).
        No trailing spaces allowed.


        :param display_name: The display_name of this ScheduledTaskSummary.
        :type: str
        """
        self._display_name = display_name

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this ScheduledTaskSummary.
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
        Example: `{\"bar-key\": \"value\"}`


        :return: The freeform_tags of this ScheduledTaskSummary.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this ScheduledTaskSummary.
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
        Example: `{\"bar-key\": \"value\"}`


        :param freeform_tags: The freeform_tags of this ScheduledTaskSummary.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this ScheduledTaskSummary.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :return: The defined_tags of this ScheduledTaskSummary.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this ScheduledTaskSummary.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :param defined_tags: The defined_tags of this ScheduledTaskSummary.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    @property
    def last_execution_status(self):
        """
        Gets the last_execution_status of this ScheduledTaskSummary.
        The most recent task execution status.

        Allowed values for this property are: "FAILED", "SUCCEEDED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The last_execution_status of this ScheduledTaskSummary.
        :rtype: str
        """
        return self._last_execution_status

    @last_execution_status.setter
    def last_execution_status(self, last_execution_status):
        """
        Sets the last_execution_status of this ScheduledTaskSummary.
        The most recent task execution status.


        :param last_execution_status: The last_execution_status of this ScheduledTaskSummary.
        :type: str
        """
        allowed_values = ["FAILED", "SUCCEEDED"]
        if not value_allowed_none_or_none_sentinel(last_execution_status, allowed_values):
            last_execution_status = 'UNKNOWN_ENUM_VALUE'
        self._last_execution_status = last_execution_status

    @property
    def time_last_executed(self):
        """
        Gets the time_last_executed of this ScheduledTaskSummary.
        The date and time the scheduled task last executed, in the format defined by RFC3339.


        :return: The time_last_executed of this ScheduledTaskSummary.
        :rtype: datetime
        """
        return self._time_last_executed

    @time_last_executed.setter
    def time_last_executed(self, time_last_executed):
        """
        Sets the time_last_executed of this ScheduledTaskSummary.
        The date and time the scheduled task last executed, in the format defined by RFC3339.


        :param time_last_executed: The time_last_executed of this ScheduledTaskSummary.
        :type: datetime
        """
        self._time_last_executed = time_last_executed

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .boot_volume_source_details import BootVolumeSourceDetails
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class BootVolumeSourceFromBootVolumeReplicaDetails(BootVolumeSourceDetails):
    """
    Specifies the source boot volume replica which the boot volume will be created from.
    The boot volume replica shoulbe be in the same availability domain as the boot volume.
    Only one volume can be created from a replica at the same time.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new BootVolumeSourceFromBootVolumeReplicaDetails object with values from keyword arguments. The default value of the :py:attr:`~oci.core.models.BootVolumeSourceFromBootVolumeReplicaDetails.type` attribute
        of this class is ``bootVolumeReplica`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param type:
            The value to assign to the type property of this BootVolumeSourceFromBootVolumeReplicaDetails.
        :type type: str

        :param id:
            The value to assign to the id property of this BootVolumeSourceFromBootVolumeReplicaDetails.
        :type id: str

        """
        self.swagger_types = {
            'type': 'str',
            'id': 'str'
        }

        self.attribute_map = {
            'type': 'type',
            'id': 'id'
        }

        self._type = None
        self._id = None
        self._type = 'bootVolumeReplica'

    @property
    def id(self):
        """
        **[Required]** Gets the id of this BootVolumeSourceFromBootVolumeReplicaDetails.
        The OCID of the boot volume replica.


        :return: The id of this BootVolumeSourceFromBootVolumeReplicaDetails.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this BootVolumeSourceFromBootVolumeReplicaDetails.
        The OCID of the boot volume replica.


        :param id: The id of this BootVolumeSourceFromBootVolumeReplicaDetails.
        :type: str
        """
        self._id = id

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class AbstractCommandDescriptor(object):
    """
    Generic command descriptor defining all attributes common to all querylanguage commands for parse output.
    """

    #: A constant which can be used with the name property of a AbstractCommandDescriptor.
    #: This constant has a value of "COMMAND"
    NAME_COMMAND = "COMMAND"

    #: A constant which can be used with the name property of a AbstractCommandDescriptor.
    #: This constant has a value of "SEARCH"
    NAME_SEARCH = "SEARCH"

    #: A constant which can be used with the name property of a AbstractCommandDescriptor.
    #: This constant has a value of "STATS"
    NAME_STATS = "STATS"

    #: A constant which can be used with the name property of a AbstractCommandDescriptor.
    #: This constant has a value of "TIME_STATS"
    NAME_TIME_STATS = "TIME_STATS"

    #: A constant which can be used with the name property of a AbstractCommandDescriptor.
    #: This constant has a value of "SORT"
    NAME_SORT = "SORT"

    #: A constant which can be used with the name property of a AbstractCommandDescriptor.
    #: This constant has a value of "FIELDS"
    NAME_FIELDS = "FIELDS"

    #: A constant which can be used with the name property of a AbstractCommandDescriptor.
    #: This constant has a value of "ADD_FIELDS"
    NAME_ADD_FIELDS = "ADD_FIELDS"

    #: A constant which can be used with the name property of a AbstractCommandDescriptor.
    #: This constant has a value of "LINK"
    NAME_LINK = "LINK"

    #: A constant which can be used with the name property of a AbstractCommandDescriptor.
    #: This constant has a value of "LINK_DETAILS"
    NAME_LINK_DETAILS = "LINK_DETAILS"

    #: A constant which can be used with the name property of a AbstractCommandDescriptor.
    #: This constant has a value of "CLUSTER"
    NAME_CLUSTER = "CLUSTER"

    #: A constant which can be used with the name property of a AbstractCommandDescriptor.
    #: This constant has a value of "CLUSTER_DETAILS"
    NAME_CLUSTER_DETAILS = "CLUSTER_DETAILS"

    #: A constant which can be used with the name property of a AbstractCommandDescriptor.
    #: This constant has a value of "CLUSTER_SPLIT"
    NAME_CLUSTER_SPLIT = "CLUSTER_SPLIT"

    #: A constant which can be used with the name property of a AbstractCommandDescriptor.
    #: This constant has a value of "EVAL"
    NAME_EVAL = "EVAL"

    #: A constant which can be used with the name property of a AbstractCommandDescriptor.
    #: This constant has a value of "EXTRACT"
    NAME_EXTRACT = "EXTRACT"

    #: A constant which can be used with the name property of a AbstractCommandDescriptor.
    #: This constant has a value of "EVENT_STATS"
    NAME_EVENT_STATS = "EVENT_STATS"

    #: A constant which can be used with the name property of a AbstractCommandDescriptor.
    #: This constant has a value of "BUCKET"
    NAME_BUCKET = "BUCKET"

    #: A constant which can be used with the name property of a AbstractCommandDescriptor.
    #: This constant has a value of "CLASSIFY"
    NAME_CLASSIFY = "CLASSIFY"

    #: A constant which can be used with the name property of a AbstractCommandDescriptor.
    #: This constant has a value of "TOP"
    NAME_TOP = "TOP"

    #: A constant which can be used with the name property of a AbstractCommandDescriptor.
    #: This constant has a value of "BOTTOM"
    NAME_BOTTOM = "BOTTOM"

    #: A constant which can be used with the name property of a AbstractCommandDescriptor.
    #: This constant has a value of "HEAD"
    NAME_HEAD = "HEAD"

    #: A constant which can be used with the name property of a AbstractCommandDescriptor.
    #: This constant has a value of "TAIL"
    NAME_TAIL = "TAIL"

    #: A constant which can be used with the name property of a AbstractCommandDescriptor.
    #: This constant has a value of "FIELD_SUMMARY"
    NAME_FIELD_SUMMARY = "FIELD_SUMMARY"

    #: A constant which can be used with the name property of a AbstractCommandDescriptor.
    #: This constant has a value of "REGEX"
    NAME_REGEX = "REGEX"

    #: A constant which can be used with the name property of a AbstractCommandDescriptor.
    #: This constant has a value of "RENAME"
    NAME_RENAME = "RENAME"

    #: A constant which can be used with the name property of a AbstractCommandDescriptor.
    #: This constant has a value of "TIME_COMPARE"
    NAME_TIME_COMPARE = "TIME_COMPARE"

    #: A constant which can be used with the name property of a AbstractCommandDescriptor.
    #: This constant has a value of "WHERE"
    NAME_WHERE = "WHERE"

    #: A constant which can be used with the name property of a AbstractCommandDescriptor.
    #: This constant has a value of "CLUSTER_COMPARE"
    NAME_CLUSTER_COMPARE = "CLUSTER_COMPARE"

    #: A constant which can be used with the name property of a AbstractCommandDescriptor.
    #: This constant has a value of "DELETE"
    NAME_DELETE = "DELETE"

    #: A constant which can be used with the name property of a AbstractCommandDescriptor.
    #: This constant has a value of "DELTA"
    NAME_DELTA = "DELTA"

    #: A constant which can be used with the name property of a AbstractCommandDescriptor.
    #: This constant has a value of "DISTINCT"
    NAME_DISTINCT = "DISTINCT"

    #: A constant which can be used with the name property of a AbstractCommandDescriptor.
    #: This constant has a value of "SEARCH_LOOKUP"
    NAME_SEARCH_LOOKUP = "SEARCH_LOOKUP"

    #: A constant which can be used with the name property of a AbstractCommandDescriptor.
    #: This constant has a value of "LOOKUP"
    NAME_LOOKUP = "LOOKUP"

    #: A constant which can be used with the name property of a AbstractCommandDescriptor.
    #: This constant has a value of "DEMO_MODE"
    NAME_DEMO_MODE = "DEMO_MODE"

    #: A constant which can be used with the name property of a AbstractCommandDescriptor.
    #: This constant has a value of "MACRO"
    NAME_MACRO = "MACRO"

    #: A constant which can be used with the name property of a AbstractCommandDescriptor.
    #: This constant has a value of "MULTI_SEARCH"
    NAME_MULTI_SEARCH = "MULTI_SEARCH"

    #: A constant which can be used with the name property of a AbstractCommandDescriptor.
    #: This constant has a value of "HIGHLIGHT"
    NAME_HIGHLIGHT = "HIGHLIGHT"

    #: A constant which can be used with the name property of a AbstractCommandDescriptor.
    #: This constant has a value of "HIGHLIGHT_ROWS"
    NAME_HIGHLIGHT_ROWS = "HIGHLIGHT_ROWS"

    #: A constant which can be used with the name property of a AbstractCommandDescriptor.
    #: This constant has a value of "HIGHLIGHT_GROUPS"
    NAME_HIGHLIGHT_GROUPS = "HIGHLIGHT_GROUPS"

    #: A constant which can be used with the name property of a AbstractCommandDescriptor.
    #: This constant has a value of "CREATE_VIEW"
    NAME_CREATE_VIEW = "CREATE_VIEW"

    #: A constant which can be used with the name property of a AbstractCommandDescriptor.
    #: This constant has a value of "MAP"
    NAME_MAP = "MAP"

    #: A constant which can be used with the name property of a AbstractCommandDescriptor.
    #: This constant has a value of "NLP"
    NAME_NLP = "NLP"

    #: A constant which can be used with the name property of a AbstractCommandDescriptor.
    #: This constant has a value of "COMPARE"
    NAME_COMPARE = "COMPARE"

    def __init__(self, **kwargs):
        """
        Initializes a new AbstractCommandDescriptor object with values from keyword arguments. This class has the following subclasses and if you are using this class as input
        to a service operations then you should favor using a subclass over the base class:

        * :class:`~oci.log_analytics.models.TopCommandDescriptor`
        * :class:`~oci.log_analytics.models.HighlightCommandDescriptor`
        * :class:`~oci.log_analytics.models.MultiSearchCommandDescriptor`
        * :class:`~oci.log_analytics.models.CompareCommandDescriptor`
        * :class:`~oci.log_analytics.models.StatsCommandDescriptor`
        * :class:`~oci.log_analytics.models.TimeCompareCommandDescriptor`
        * :class:`~oci.log_analytics.models.TailCommandDescriptor`
        * :class:`~oci.log_analytics.models.RegexCommandDescriptor`
        * :class:`~oci.log_analytics.models.DeltaCommandDescriptor`
        * :class:`~oci.log_analytics.models.LookupCommandDescriptor`
        * :class:`~oci.log_analytics.models.DemoModeCommandDescriptor`
        * :class:`~oci.log_analytics.models.FieldSummaryCommandDescriptor`
        * :class:`~oci.log_analytics.models.MapCommandDescriptor`
        * :class:`~oci.log_analytics.models.EventStatsCommandDescriptor`
        * :class:`~oci.log_analytics.models.HighlightGroupsCommandDescriptor`
        * :class:`~oci.log_analytics.models.WhereCommandDescriptor`
        * :class:`~oci.log_analytics.models.ClusterSplitCommandDescriptor`
        * :class:`~oci.log_analytics.models.TimeStatsCommandDescriptor`
        * :class:`~oci.log_analytics.models.ClusterCommandDescriptor`
        * :class:`~oci.log_analytics.models.ClusterDetailsCommandDescriptor`
        * :class:`~oci.log_analytics.models.DeleteCommandDescriptor`
        * :class:`~oci.log_analytics.models.ClusterCompareCommandDescriptor`
        * :class:`~oci.log_analytics.models.SearchCommandDescriptor`
        * :class:`~oci.log_analytics.models.BucketCommandDescriptor`
        * :class:`~oci.log_analytics.models.CommandDescriptor`
        * :class:`~oci.log_analytics.models.DistinctCommandDescriptor`
        * :class:`~oci.log_analytics.models.LinkCommandDescriptor`
        * :class:`~oci.log_analytics.models.SortCommandDescriptor`
        * :class:`~oci.log_analytics.models.ExtractCommandDescriptor`
        * :class:`~oci.log_analytics.models.NlpCommandDescriptor`
        * :class:`~oci.log_analytics.models.BottomCommandDescriptor`
        * :class:`~oci.log_analytics.models.FieldsCommandDescriptor`
        * :class:`~oci.log_analytics.models.HighlightRowsCommandDescriptor`
        * :class:`~oci.log_analytics.models.MacroCommandDescriptor`
        * :class:`~oci.log_analytics.models.ClassifyCommandDescriptor`
        * :class:`~oci.log_analytics.models.LinkDetailsCommandDescriptor`
        * :class:`~oci.log_analytics.models.SearchLookupCommandDescriptor`
        * :class:`~oci.log_analytics.models.HeadCommandDescriptor`
        * :class:`~oci.log_analytics.models.CreateViewCommandDescriptor`
        * :class:`~oci.log_analytics.models.AddFieldsCommandDescriptor`
        * :class:`~oci.log_analytics.models.EvalCommandDescriptor`
        * :class:`~oci.log_analytics.models.RenameCommandDescriptor`

        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param name:
            The value to assign to the name property of this AbstractCommandDescriptor.
            Allowed values for this property are: "COMMAND", "SEARCH", "STATS", "TIME_STATS", "SORT", "FIELDS", "ADD_FIELDS", "LINK", "LINK_DETAILS", "CLUSTER", "CLUSTER_DETAILS", "CLUSTER_SPLIT", "EVAL", "EXTRACT", "EVENT_STATS", "BUCKET", "CLASSIFY", "TOP", "BOTTOM", "HEAD", "TAIL", "FIELD_SUMMARY", "REGEX", "RENAME", "TIME_COMPARE", "WHERE", "CLUSTER_COMPARE", "DELETE", "DELTA", "DISTINCT", "SEARCH_LOOKUP", "LOOKUP", "DEMO_MODE", "MACRO", "MULTI_SEARCH", "HIGHLIGHT", "HIGHLIGHT_ROWS", "HIGHLIGHT_GROUPS", "CREATE_VIEW", "MAP", "NLP", "COMPARE", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type name: str

        :param display_query_string:
            The value to assign to the display_query_string property of this AbstractCommandDescriptor.
        :type display_query_string: str

        :param internal_query_string:
            The value to assign to the internal_query_string property of this AbstractCommandDescriptor.
        :type internal_query_string: str

        :param category:
            The value to assign to the category property of this AbstractCommandDescriptor.
        :type category: str

        :param referenced_fields:
            The value to assign to the referenced_fields property of this AbstractCommandDescriptor.
        :type referenced_fields: list[oci.log_analytics.models.AbstractField]

        :param declared_fields:
            The value to assign to the declared_fields property of this AbstractCommandDescriptor.
        :type declared_fields: list[oci.log_analytics.models.AbstractField]

        """
        self.swagger_types = {
            'name': 'str',
            'display_query_string': 'str',
            'internal_query_string': 'str',
            'category': 'str',
            'referenced_fields': 'list[AbstractField]',
            'declared_fields': 'list[AbstractField]'
        }

        self.attribute_map = {
            'name': 'name',
            'display_query_string': 'displayQueryString',
            'internal_query_string': 'internalQueryString',
            'category': 'category',
            'referenced_fields': 'referencedFields',
            'declared_fields': 'declaredFields'
        }

        self._name = None
        self._display_query_string = None
        self._internal_query_string = None
        self._category = None
        self._referenced_fields = None
        self._declared_fields = None

    @staticmethod
    def get_subtype(object_dictionary):
        """
        Given the hash representation of a subtype of this class,
        use the info in the hash to return the class of the subtype.
        """
        type = object_dictionary['name']

        if type == 'TOP':
            return 'TopCommandDescriptor'

        if type == 'HIGHLIGHT':
            return 'HighlightCommandDescriptor'

        if type == 'MULTI_SEARCH':
            return 'MultiSearchCommandDescriptor'

        if type == 'COMPARE':
            return 'CompareCommandDescriptor'

        if type == 'STATS':
            return 'StatsCommandDescriptor'

        if type == 'TIME_COMPARE':
            return 'TimeCompareCommandDescriptor'

        if type == 'TAIL':
            return 'TailCommandDescriptor'

        if type == 'REGEX':
            return 'RegexCommandDescriptor'

        if type == 'DELTA':
            return 'DeltaCommandDescriptor'

        if type == 'LOOKUP':
            return 'LookupCommandDescriptor'

        if type == 'DEMO_MODE':
            return 'DemoModeCommandDescriptor'

        if type == 'FIELD_SUMMARY':
            return 'FieldSummaryCommandDescriptor'

        if type == 'MAP':
            return 'MapCommandDescriptor'

        if type == 'EVENT_STATS':
            return 'EventStatsCommandDescriptor'

        if type == 'HIGHLIGHT_GROUPS':
            return 'HighlightGroupsCommandDescriptor'

        if type == 'WHERE':
            return 'WhereCommandDescriptor'

        if type == 'CLUSTER_SPLIT':
            return 'ClusterSplitCommandDescriptor'

        if type == 'TIME_STATS':
            return 'TimeStatsCommandDescriptor'

        if type == 'CLUSTER':
            return 'ClusterCommandDescriptor'

        if type == 'CLUSTER_DETAILS':
            return 'ClusterDetailsCommandDescriptor'

        if type == 'DELETE':
            return 'DeleteCommandDescriptor'

        if type == 'CLUSTER_COMPARE':
            return 'ClusterCompareCommandDescriptor'

        if type == 'SEARCH':
            return 'SearchCommandDescriptor'

        if type == 'BUCKET':
            return 'BucketCommandDescriptor'

        if type == 'COMMAND':
            return 'CommandDescriptor'

        if type == 'DISTINCT':
            return 'DistinctCommandDescriptor'

        if type == 'LINK':
            return 'LinkCommandDescriptor'

        if type == 'SORT':
            return 'SortCommandDescriptor'

        if type == 'EXTRACT':
            return 'ExtractCommandDescriptor'

        if type == 'NLP':
            return 'NlpCommandDescriptor'

        if type == 'BOTTOM':
            return 'BottomCommandDescriptor'

        if type == 'FIELDS':
            return 'FieldsCommandDescriptor'

        if type == 'HIGHLIGHT_ROWS':
            return 'HighlightRowsCommandDescriptor'

        if type == 'MACRO':
            return 'MacroCommandDescriptor'

        if type == 'CLASSIFY':
            return 'ClassifyCommandDescriptor'

        if type == 'LINK_DETAILS':
            return 'LinkDetailsCommandDescriptor'

        if type == 'SEARCH_LOOKUP':
            return 'SearchLookupCommandDescriptor'

        if type == 'HEAD':
            return 'HeadCommandDescriptor'

        if type == 'CREATE_VIEW':
            return 'CreateViewCommandDescriptor'

        if type == 'ADD_FIELDS':
            return 'AddFieldsCommandDescriptor'

        if type == 'EVAL':
            return 'EvalCommandDescriptor'

        if type == 'RENAME':
            return 'RenameCommandDescriptor'
        else:
            return 'AbstractCommandDescriptor'

    @property
    def name(self):
        """
        **[Required]** Gets the name of this AbstractCommandDescriptor.
        Name of querylanguage command

        Allowed values for this property are: "COMMAND", "SEARCH", "STATS", "TIME_STATS", "SORT", "FIELDS", "ADD_FIELDS", "LINK", "LINK_DETAILS", "CLUSTER", "CLUSTER_DETAILS", "CLUSTER_SPLIT", "EVAL", "EXTRACT", "EVENT_STATS", "BUCKET", "CLASSIFY", "TOP", "BOTTOM", "HEAD", "TAIL", "FIELD_SUMMARY", "REGEX", "RENAME", "TIME_COMPARE", "WHERE", "CLUSTER_COMPARE", "DELETE", "DELTA", "DISTINCT", "SEARCH_LOOKUP", "LOOKUP", "DEMO_MODE", "MACRO", "MULTI_SEARCH", "HIGHLIGHT", "HIGHLIGHT_ROWS", "HIGHLIGHT_GROUPS", "CREATE_VIEW", "MAP", "NLP", "COMPARE", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The name of this AbstractCommandDescriptor.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this AbstractCommandDescriptor.
        Name of querylanguage command


        :param name: The name of this AbstractCommandDescriptor.
        :type: str
        """
        allowed_values = ["COMMAND", "SEARCH", "STATS", "TIME_STATS", "SORT", "FIELDS", "ADD_FIELDS", "LINK", "LINK_DETAILS", "CLUSTER", "CLUSTER_DETAILS", "CLUSTER_SPLIT", "EVAL", "EXTRACT", "EVENT_STATS", "BUCKET", "CLASSIFY", "TOP", "BOTTOM", "HEAD", "TAIL", "FIELD_SUMMARY", "REGEX", "RENAME", "TIME_COMPARE", "WHERE", "CLUSTER_COMPARE", "DELETE", "DELTA", "DISTINCT", "SEARCH_LOOKUP", "LOOKUP", "DEMO_MODE", "MACRO", "MULTI_SEARCH", "HIGHLIGHT", "HIGHLIGHT_ROWS", "HIGHLIGHT_GROUPS", "CREATE_VIEW", "MAP", "NLP", "COMPARE"]
        if not value_allowed_none_or_none_sentinel(name, allowed_values):
            name = 'UNKNOWN_ENUM_VALUE'
        self._name = name

    @property
    def display_query_string(self):
        """
        **[Required]** Gets the display_query_string of this AbstractCommandDescriptor.
        Command fragment display string from user specified query string formatted by query builder.


        :return: The display_query_string of this AbstractCommandDescriptor.
        :rtype: str
        """
        return self._display_query_string

    @display_query_string.setter
    def display_query_string(self, display_query_string):
        """
        Sets the display_query_string of this AbstractCommandDescriptor.
        Command fragment display string from user specified query string formatted by query builder.


        :param display_query_string: The display_query_string of this AbstractCommandDescriptor.
        :type: str
        """
        self._display_query_string = display_query_string

    @property
    def internal_query_string(self):
        """
        **[Required]** Gets the internal_query_string of this AbstractCommandDescriptor.
        Command fragment internal string from user specified query string formatted by query builder.


        :return: The internal_query_string of this AbstractCommandDescriptor.
        :rtype: str
        """
        return self._internal_query_string

    @internal_query_string.setter
    def internal_query_string(self, internal_query_string):
        """
        Sets the internal_query_string of this AbstractCommandDescriptor.
        Command fragment internal string from user specified query string formatted by query builder.


        :param internal_query_string: The internal_query_string of this AbstractCommandDescriptor.
        :type: str
        """
        self._internal_query_string = internal_query_string

    @property
    def category(self):
        """
        Gets the category of this AbstractCommandDescriptor.
        querylanguage command designation for example; reporting vs filtering


        :return: The category of this AbstractCommandDescriptor.
        :rtype: str
        """
        return self._category

    @category.setter
    def category(self, category):
        """
        Sets the category of this AbstractCommandDescriptor.
        querylanguage command designation for example; reporting vs filtering


        :param category: The category of this AbstractCommandDescriptor.
        :type: str
        """
        self._category = category

    @property
    def referenced_fields(self):
        """
        Gets the referenced_fields of this AbstractCommandDescriptor.
        Fields referenced in command fragment from user specified query string.


        :return: The referenced_fields of this AbstractCommandDescriptor.
        :rtype: list[oci.log_analytics.models.AbstractField]
        """
        return self._referenced_fields

    @referenced_fields.setter
    def referenced_fields(self, referenced_fields):
        """
        Sets the referenced_fields of this AbstractCommandDescriptor.
        Fields referenced in command fragment from user specified query string.


        :param referenced_fields: The referenced_fields of this AbstractCommandDescriptor.
        :type: list[oci.log_analytics.models.AbstractField]
        """
        self._referenced_fields = referenced_fields

    @property
    def declared_fields(self):
        """
        Gets the declared_fields of this AbstractCommandDescriptor.
        Fields declared in command fragment from user specified query string.


        :return: The declared_fields of this AbstractCommandDescriptor.
        :rtype: list[oci.log_analytics.models.AbstractField]
        """
        return self._declared_fields

    @declared_fields.setter
    def declared_fields(self, declared_fields):
        """
        Sets the declared_fields of this AbstractCommandDescriptor.
        Fields declared in command fragment from user specified query string.


        :param declared_fields: The declared_fields of this AbstractCommandDescriptor.
        :type: list[oci.log_analytics.models.AbstractField]
        """
        self._declared_fields = declared_fields

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class RedirectUri(object):
    """
    An object that defines the redirect URI applied to the original request. The object property values compose the
    redirect URI.

    **NOTE:** The Load Balancing service cannot automatically detect or avoid infinite redirects. Be sure to provide
    meaningful, complete, and correct field values. If any component field of this object has no value, the system
    retains the value from the incoming HTTP request URI.

    For example, if you specify only the protocol field `https`, and the incoming request URI is
    `http://example.com:8080`, the resulting runtime redirect URI is `https://example.com:8080`. The system retains
    the host and port from the incoming URI and does not automatically change the port setting from `8080` to `443`.

    Be sure to configure valid percent-encoding (URL encoding) when needed.

    In addition to static string values, you can use the following tokens to construct the redirect URI. These tokens
    extract values from the incoming HTTP request URI.

    *  {protocol} : The protocol from the incoming HTTP request URI.
    *  {host}     : The domain name from the incoming HTTP request URI.
    *  {port}     : The port from the incoming HTTP request URI.
    *  {path}     : The path from the incoming HTTP request URI.
    *  {query}    : The query string from the incoming HTTP request URI.

    The tokens are case sensitive. For example, `{host}` is a valid token, but `{HOST}` is not.

    You can retain the literal characters of a token when you specify values for the path and query properties of the
    redirect URI. Use a backslash (\\\\) as the escape character for the \\\\, {, and } characters. For example, if the
    incoming HTTP request URI is `/video`, the path property value:

    `/example{path}123\\{path\\}`

    appears in the constructed redirect URI as:

    `/example/video123{path}`
    """

    def __init__(self, **kwargs):
        """
        Initializes a new RedirectUri object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param protocol:
            The value to assign to the protocol property of this RedirectUri.
        :type protocol: str

        :param host:
            The value to assign to the host property of this RedirectUri.
        :type host: str

        :param port:
            The value to assign to the port property of this RedirectUri.
        :type port: int

        :param path:
            The value to assign to the path property of this RedirectUri.
        :type path: str

        :param query:
            The value to assign to the query property of this RedirectUri.
        :type query: str

        """
        self.swagger_types = {
            'protocol': 'str',
            'host': 'str',
            'port': 'int',
            'path': 'str',
            'query': 'str'
        }

        self.attribute_map = {
            'protocol': 'protocol',
            'host': 'host',
            'port': 'port',
            'path': 'path',
            'query': 'query'
        }

        self._protocol = None
        self._host = None
        self._port = None
        self._path = None
        self._query = None

    @property
    def protocol(self):
        """
        Gets the protocol of this RedirectUri.
        The HTTP protocol to use in the redirect URI.

        When this value is null, not set, or set to `{protocol}`, the service preserves the original protocol from the
        incoming HTTP request URI. Allowed values are:

        *  HTTP
        *  HTTPS
        *  {protocol}

        `{protocol}` is the only valid token for this property. It can appear only once in the value string.

        Example: `HTTPS`


        :return: The protocol of this RedirectUri.
        :rtype: str
        """
        return self._protocol

    @protocol.setter
    def protocol(self, protocol):
        """
        Sets the protocol of this RedirectUri.
        The HTTP protocol to use in the redirect URI.

        When this value is null, not set, or set to `{protocol}`, the service preserves the original protocol from the
        incoming HTTP request URI. Allowed values are:

        *  HTTP
        *  HTTPS
        *  {protocol}

        `{protocol}` is the only valid token for this property. It can appear only once in the value string.

        Example: `HTTPS`


        :param protocol: The protocol of this RedirectUri.
        :type: str
        """
        self._protocol = protocol

    @property
    def host(self):
        """
        Gets the host of this RedirectUri.
        The valid domain name (hostname) or IP address to use in the redirect URI.

        When this value is null, not set, or set to `{host}`, the service preserves the original domain name from the
        incoming HTTP request URI.

        All RedirectUri tokens are valid for this property. You can use any token more than once.

        Curly braces are valid in this property only to surround tokens, such as `{host}`

        Examples:

        *  **example.com** appears as `example.com` in the redirect URI.

        *  **in{host}** appears as `inexample.com` in the redirect URI if `example.com` is the hostname in the
           incoming HTTP request URI.

        *  **{port}{host}** appears as `8081example.com` in the redirect URI if `example.com` is the hostname and
           the port is `8081` in the incoming HTTP request URI.


        :return: The host of this RedirectUri.
        :rtype: str
        """
        return self._host

    @host.setter
    def host(self, host):
        """
        Sets the host of this RedirectUri.
        The valid domain name (hostname) or IP address to use in the redirect URI.

        When this value is null, not set, or set to `{host}`, the service preserves the original domain name from the
        incoming HTTP request URI.

        All RedirectUri tokens are valid for this property. You can use any token more than once.

        Curly braces are valid in this property only to surround tokens, such as `{host}`

        Examples:

        *  **example.com** appears as `example.com` in the redirect URI.

        *  **in{host}** appears as `inexample.com` in the redirect URI if `example.com` is the hostname in the
           incoming HTTP request URI.

        *  **{port}{host}** appears as `8081example.com` in the redirect URI if `example.com` is the hostname and
           the port is `8081` in the incoming HTTP request URI.


        :param host: The host of this RedirectUri.
        :type: str
        """
        self._host = host

    @property
    def port(self):
        """
        Gets the port of this RedirectUri.
        The communication port to use in the redirect URI.

        Valid values include integers from 1 to 65535.

        When this value is null, the service preserves the original port from the incoming HTTP request URI.

        Example: `8081`


        :return: The port of this RedirectUri.
        :rtype: int
        """
        return self._port

    @port.setter
    def port(self, port):
        """
        Sets the port of this RedirectUri.
        The communication port to use in the redirect URI.

        Valid values include integers from 1 to 65535.

        When this value is null, the service preserves the original port from the incoming HTTP request URI.

        Example: `8081`


        :param port: The port of this RedirectUri.
        :type: int
        """
        self._port = port

    @property
    def path(self):
        """
        Gets the path of this RedirectUri.
        The HTTP URI path to use in the redirect URI.

        When this value is null, not set, or set to `{path}`, the service preserves the original path from the
        incoming HTTP request URI. To omit the path from the redirect URI, set this value to an empty string, \"\".

        All RedirectUri tokens are valid for this property. You can use any token more than once.

        The path string must begin with `/` if it does not begin with the `{path}` token.

        Examples:

        *  __/example/video/123__ appears as `/example/video/123` in the redirect URI.

        *  __/example{path}__ appears as `/example/video/123` in the redirect URI if `/video/123` is the path in the
           incoming HTTP request URI.

        *  __{path}/123__ appears as `/example/video/123` in the redirect URI if `/example/video` is the path in the
           incoming HTTP request URI.

        *  __{path}123__ appears as `/example/video123` in the redirect URI if `/example/video` is the path in the
           incoming HTTP request URI.

        *  __/{host}/123__ appears as `/example.com/123` in the redirect URI if `example.com` is the hostname
           in the incoming HTTP request URI.

        *  __/{host}/{port}__ appears as `/example.com/123` in the redirect URI if `example.com` is the hostname and
           `123` is the port in the incoming HTTP request URI.

        *  __/{query}__ appears as `/lang=en` in the redirect URI if the query is `lang=en` in the incoming HTTP
           request URI.


        :return: The path of this RedirectUri.
        :rtype: str
        """
        return self._path

    @path.setter
    def path(self, path):
        """
        Sets the path of this RedirectUri.
        The HTTP URI path to use in the redirect URI.

        When this value is null, not set, or set to `{path}`, the service preserves the original path from the
        incoming HTTP request URI. To omit the path from the redirect URI, set this value to an empty string, \"\".

        All RedirectUri tokens are valid for this property. You can use any token more than once.

        The path string must begin with `/` if it does not begin with the `{path}` token.

        Examples:

        *  __/example/video/123__ appears as `/example/video/123` in the redirect URI.

        *  __/example{path}__ appears as `/example/video/123` in the redirect URI if `/video/123` is the path in the
           incoming HTTP request URI.

        *  __{path}/123__ appears as `/example/video/123` in the redirect URI if `/example/video` is the path in the
           incoming HTTP request URI.

        *  __{path}123__ appears as `/example/video123` in the redirect URI if `/example/video` is the path in the
           incoming HTTP request URI.

        *  __/{host}/123__ appears as `/example.com/123` in the redirect URI if `example.com` is the hostname
           in the incoming HTTP request URI.

        *  __/{host}/{port}__ appears as `/example.com/123` in the redirect URI if `example.com` is the hostname and
           `123` is the port in the incoming HTTP request URI.

        *  __/{query}__ appears as `/lang=en` in the redirect URI if the query is `lang=en` in the incoming HTTP
           request URI.


        :param path: The path of this RedirectUri.
        :type: str
        """
        self._path = path

    @property
    def query(self):
        """
        Gets the query of this RedirectUri.
        The query string to use in the redirect URI.

        When this value is null, not set, or set to `{query}`, the service preserves the original query parameters
        from the incoming HTTP request URI.

        All `RedirectUri` tokens are valid for this property. You can use any token more than once.

        If the query string does not begin with the `{query}` token, it must begin with the question mark (?) character.

        You can specify multiple query parameters as a single string. Separate each query parameter with an ampersand
        (&) character. To omit all incoming query parameters from the redirect URI, set this value to an empty
        string, \"\".

        If the specified query string results in a redirect URI ending with `?` or `&`, the last character is truncated.
        For example, if the incoming URI is `http://host.com:8080/documents` and the query property value is
        `?lang=en&{query}`, the redirect URI is `http://host.com:8080/documents?lang=en`. The system
        truncates the final ampersand (&) because the incoming URI included no value to replace the {query} token.

        Examples:
        * **lang=en&time_zone=PST** appears as `lang=en&time_zone=PST` in the redirect URI.

        * **{query}** appears as `lang=en&time_zone=PST` in the redirect URI if `lang=en&time_zone=PST` is the query
          string in the incoming HTTP request. If the incoming HTTP request has no query parameters, the `{query}`
          token renders as an empty string.

        * **lang=en&{query}&time_zone=PST** appears as `lang=en&country=us&time_zone=PST` in the redirect URI if
          `country=us` is the query string in the incoming HTTP request. If the incoming HTTP request has no query
          parameters, this value renders as `lang=en&time_zone=PST`.

        *  **protocol={protocol}&hostname={host}** appears as `protocol=http&hostname=example.com` in the redirect
           URI if the protocol is `HTTP` and the hostname is `example.com` in the incoming HTTP request.

        *  **port={port}&hostname={host}** appears as `port=8080&hostname=example.com` in the redirect URI if the
           port is `8080` and the hostname is `example.com` in the incoming HTTP request URI.


        :return: The query of this RedirectUri.
        :rtype: str
        """
        return self._query

    @query.setter
    def query(self, query):
        """
        Sets the query of this RedirectUri.
        The query string to use in the redirect URI.

        When this value is null, not set, or set to `{query}`, the service preserves the original query parameters
        from the incoming HTTP request URI.

        All `RedirectUri` tokens are valid for this property. You can use any token more than once.

        If the query string does not begin with the `{query}` token, it must begin with the question mark (?) character.

        You can specify multiple query parameters as a single string. Separate each query parameter with an ampersand
        (&) character. To omit all incoming query parameters from the redirect URI, set this value to an empty
        string, \"\".

        If the specified query string results in a redirect URI ending with `?` or `&`, the last character is truncated.
        For example, if the incoming URI is `http://host.com:8080/documents` and the query property value is
        `?lang=en&{query}`, the redirect URI is `http://host.com:8080/documents?lang=en`. The system
        truncates the final ampersand (&) because the incoming URI included no value to replace the {query} token.

        Examples:
        * **lang=en&time_zone=PST** appears as `lang=en&time_zone=PST` in the redirect URI.

        * **{query}** appears as `lang=en&time_zone=PST` in the redirect URI if `lang=en&time_zone=PST` is the query
          string in the incoming HTTP request. If the incoming HTTP request has no query parameters, the `{query}`
          token renders as an empty string.

        * **lang=en&{query}&time_zone=PST** appears as `lang=en&country=us&time_zone=PST` in the redirect URI if
          `country=us` is the query string in the incoming HTTP request. If the incoming HTTP request has no query
          parameters, this value renders as `lang=en&time_zone=PST`.

        *  **protocol={protocol}&hostname={host}** appears as `protocol=http&hostname=example.com` in the redirect
           URI if the protocol is `HTTP` and the hostname is `example.com` in the incoming HTTP request.

        *  **port={port}&hostname={host}** appears as `port=8080&hostname=example.com` in the redirect URI if the
           port is `8080` and the hostname is `example.com` in the incoming HTTP request URI.


        :param query: The query of this RedirectUri.
        :type: str
        """
        self._query = query

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class LimitValueSummary(object):
    """
    The value of a specific resource limit.
    """

    #: A constant which can be used with the scope_type property of a LimitValueSummary.
    #: This constant has a value of "GLOBAL"
    SCOPE_TYPE_GLOBAL = "GLOBAL"

    #: A constant which can be used with the scope_type property of a LimitValueSummary.
    #: This constant has a value of "REGION"
    SCOPE_TYPE_REGION = "REGION"

    #: A constant which can be used with the scope_type property of a LimitValueSummary.
    #: This constant has a value of "AD"
    SCOPE_TYPE_AD = "AD"

    def __init__(self, **kwargs):
        """
        Initializes a new LimitValueSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param name:
            The value to assign to the name property of this LimitValueSummary.
        :type name: str

        :param scope_type:
            The value to assign to the scope_type property of this LimitValueSummary.
            Allowed values for this property are: "GLOBAL", "REGION", "AD", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type scope_type: str

        :param availability_domain:
            The value to assign to the availability_domain property of this LimitValueSummary.
        :type availability_domain: str

        :param value:
            The value to assign to the value property of this LimitValueSummary.
        :type value: int

        """
        self.swagger_types = {
            'name': 'str',
            'scope_type': 'str',
            'availability_domain': 'str',
            'value': 'int'
        }

        self.attribute_map = {
            'name': 'name',
            'scope_type': 'scopeType',
            'availability_domain': 'availabilityDomain',
            'value': 'value'
        }

        self._name = None
        self._scope_type = None
        self._availability_domain = None
        self._value = None

    @property
    def name(self):
        """
        Gets the name of this LimitValueSummary.
        The resource limit name. To be used for writing policies (in case of quotas) or other programmatic calls.


        :return: The name of this LimitValueSummary.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this LimitValueSummary.
        The resource limit name. To be used for writing policies (in case of quotas) or other programmatic calls.


        :param name: The name of this LimitValueSummary.
        :type: str
        """
        self._name = name

    @property
    def scope_type(self):
        """
        Gets the scope_type of this LimitValueSummary.
        The scope type of the limit.

        Allowed values for this property are: "GLOBAL", "REGION", "AD", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The scope_type of this LimitValueSummary.
        :rtype: str
        """
        return self._scope_type

    @scope_type.setter
    def scope_type(self, scope_type):
        """
        Sets the scope_type of this LimitValueSummary.
        The scope type of the limit.


        :param scope_type: The scope_type of this LimitValueSummary.
        :type: str
        """
        allowed_values = ["GLOBAL", "REGION", "AD"]
        if not value_allowed_none_or_none_sentinel(scope_type, allowed_values):
            scope_type = 'UNKNOWN_ENUM_VALUE'
        self._scope_type = scope_type

    @property
    def availability_domain(self):
        """
        Gets the availability_domain of this LimitValueSummary.
        If present, the returned value is only specific to this availability domain.


        :return: The availability_domain of this LimitValueSummary.
        :rtype: str
        """
        return self._availability_domain

    @availability_domain.setter
    def availability_domain(self, availability_domain):
        """
        Sets the availability_domain of this LimitValueSummary.
        If present, the returned value is only specific to this availability domain.


        :param availability_domain: The availability_domain of this LimitValueSummary.
        :type: str
        """
        self._availability_domain = availability_domain

    @property
    def value(self):
        """
        Gets the value of this LimitValueSummary.
        The resource limit value.


        :return: The value of this LimitValueSummary.
        :rtype: int
        """
        return self._value

    @value.setter
    def value(self, value):
        """
        Sets the value of this LimitValueSummary.
        The resource limit value.


        :param value: The value of this LimitValueSummary.
        :type: int
        """
        self._value = value

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class UserDetails(object):
    """
    The details of a particular user.
    """

    #: A constant which can be used with the authentication_type property of a UserDetails.
    #: This constant has a value of "PASSWORD"
    AUTHENTICATION_TYPE_PASSWORD = "PASSWORD"

    #: A constant which can be used with the authentication_type property of a UserDetails.
    #: This constant has a value of "NONE"
    AUTHENTICATION_TYPE_NONE = "NONE"

    def __init__(self, **kwargs):
        """
        Initializes a new UserDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param name:
            The value to assign to the name property of this UserDetails.
        :type name: str

        :param status:
            The value to assign to the status property of this UserDetails.
        :type status: str

        :param profile:
            The value to assign to the profile property of this UserDetails.
        :type profile: str

        :param tablespace:
            The value to assign to the tablespace property of this UserDetails.
        :type tablespace: str

        :param is_user_predefined_by_oracle:
            The value to assign to the is_user_predefined_by_oracle property of this UserDetails.
        :type is_user_predefined_by_oracle: bool

        :param authentication_type:
            The value to assign to the authentication_type property of this UserDetails.
            Allowed values for this property are: "PASSWORD", "NONE"
        :type authentication_type: str

        """
        self.swagger_types = {
            'name': 'str',
            'status': 'str',
            'profile': 'str',
            'tablespace': 'str',
            'is_user_predefined_by_oracle': 'bool',
            'authentication_type': 'str'
        }

        self.attribute_map = {
            'name': 'name',
            'status': 'status',
            'profile': 'profile',
            'tablespace': 'tablespace',
            'is_user_predefined_by_oracle': 'isUserPredefinedByOracle',
            'authentication_type': 'authenticationType'
        }

        self._name = None
        self._status = None
        self._profile = None
        self._tablespace = None
        self._is_user_predefined_by_oracle = None
        self._authentication_type = None

    @property
    def name(self):
        """
        Gets the name of this UserDetails.
        The name of the user.


        :return: The name of this UserDetails.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this UserDetails.
        The name of the user.


        :param name: The name of this UserDetails.
        :type: str
        """
        self._name = name

    @property
    def status(self):
        """
        Gets the status of this UserDetails.
        The status of the user account.


        :return: The status of this UserDetails.
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """
        Sets the status of this UserDetails.
        The status of the user account.


        :param status: The status of this UserDetails.
        :type: str
        """
        self._status = status

    @property
    def profile(self):
        """
        Gets the profile of this UserDetails.
        The name of the profile assigned to the user.


        :return: The profile of this UserDetails.
        :rtype: str
        """
        return self._profile

    @profile.setter
    def profile(self, profile):
        """
        Sets the profile of this UserDetails.
        The name of the profile assigned to the user.


        :param profile: The profile of this UserDetails.
        :type: str
        """
        self._profile = profile

    @property
    def tablespace(self):
        """
        Gets the tablespace of this UserDetails.
        The default tablespace of the user.


        :return: The tablespace of this UserDetails.
        :rtype: str
        """
        return self._tablespace

    @tablespace.setter
    def tablespace(self, tablespace):
        """
        Sets the tablespace of this UserDetails.
        The default tablespace of the user.


        :param tablespace: The tablespace of this UserDetails.
        :type: str
        """
        self._tablespace = tablespace

    @property
    def is_user_predefined_by_oracle(self):
        """
        Gets the is_user_predefined_by_oracle of this UserDetails.
        Indicates whether or not the user is predefined by ORACLE.


        :return: The is_user_predefined_by_oracle of this UserDetails.
        :rtype: bool
        """
        return self._is_user_predefined_by_oracle

    @is_user_predefined_by_oracle.setter
    def is_user_predefined_by_oracle(self, is_user_predefined_by_oracle):
        """
        Sets the is_user_predefined_by_oracle of this UserDetails.
        Indicates whether or not the user is predefined by ORACLE.


        :param is_user_predefined_by_oracle: The is_user_predefined_by_oracle of this UserDetails.
        :type: bool
        """
        self._is_user_predefined_by_oracle = is_user_predefined_by_oracle

    @property
    def authentication_type(self):
        """
        Gets the authentication_type of this UserDetails.
        The authentication type of the user.

        Allowed values for this property are: "PASSWORD", "NONE"


        :return: The authentication_type of this UserDetails.
        :rtype: str
        """
        return self._authentication_type

    @authentication_type.setter
    def authentication_type(self, authentication_type):
        """
        Sets the authentication_type of this UserDetails.
        The authentication type of the user.


        :param authentication_type: The authentication_type of this UserDetails.
        :type: str
        """
        allowed_values = ["PASSWORD", "NONE"]
        if not value_allowed_none_or_none_sentinel(authentication_type, allowed_values):
            raise ValueError(
                "Invalid value for `authentication_type`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._authentication_type = authentication_type

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ParserSummaryReport(object):
    """
    ParserSummaryReport
    """

    def __init__(self, **kwargs):
        """
        Initializes a new ParserSummaryReport object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param non_oob_count:
            The value to assign to the non_oob_count property of this ParserSummaryReport.
        :type non_oob_count: int

        :param oob_count:
            The value to assign to the oob_count property of this ParserSummaryReport.
        :type oob_count: int

        """
        self.swagger_types = {
            'non_oob_count': 'int',
            'oob_count': 'int'
        }

        self.attribute_map = {
            'non_oob_count': 'nonOobCount',
            'oob_count': 'oobCount'
        }

        self._non_oob_count = None
        self._oob_count = None

    @property
    def non_oob_count(self):
        """
        Gets the non_oob_count of this ParserSummaryReport.
        The count of custom (user defined) parsers.


        :return: The non_oob_count of this ParserSummaryReport.
        :rtype: int
        """
        return self._non_oob_count

    @non_oob_count.setter
    def non_oob_count(self, non_oob_count):
        """
        Sets the non_oob_count of this ParserSummaryReport.
        The count of custom (user defined) parsers.


        :param non_oob_count: The non_oob_count of this ParserSummaryReport.
        :type: int
        """
        self._non_oob_count = non_oob_count

    @property
    def oob_count(self):
        """
        Gets the oob_count of this ParserSummaryReport.
        The count of built in parsers.


        :return: The oob_count of this ParserSummaryReport.
        :rtype: int
        """
        return self._oob_count

    @oob_count.setter
    def oob_count(self, oob_count):
        """
        Sets the oob_count of this ParserSummaryReport.
        The count of built in parsers.


        :param oob_count: The oob_count of this ParserSummaryReport.
        :type: int
        """
        self._oob_count = oob_count

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .rule_condition import RuleCondition
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class PathMatchCondition(RuleCondition):
    """
    The path string and match condition to apply when evaluating an incoming URI for redirection.
    """

    #: A constant which can be used with the operator property of a PathMatchCondition.
    #: This constant has a value of "EXACT_MATCH"
    OPERATOR_EXACT_MATCH = "EXACT_MATCH"

    #: A constant which can be used with the operator property of a PathMatchCondition.
    #: This constant has a value of "FORCE_LONGEST_PREFIX_MATCH"
    OPERATOR_FORCE_LONGEST_PREFIX_MATCH = "FORCE_LONGEST_PREFIX_MATCH"

    #: A constant which can be used with the operator property of a PathMatchCondition.
    #: This constant has a value of "PREFIX_MATCH"
    OPERATOR_PREFIX_MATCH = "PREFIX_MATCH"

    #: A constant which can be used with the operator property of a PathMatchCondition.
    #: This constant has a value of "SUFFIX_MATCH"
    OPERATOR_SUFFIX_MATCH = "SUFFIX_MATCH"

    def __init__(self, **kwargs):
        """
        Initializes a new PathMatchCondition object with values from keyword arguments. The default value of the :py:attr:`~oci.load_balancer.models.PathMatchCondition.attribute_name` attribute
        of this class is ``PATH`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param attribute_name:
            The value to assign to the attribute_name property of this PathMatchCondition.
            Allowed values for this property are: "SOURCE_IP_ADDRESS", "SOURCE_VCN_ID", "SOURCE_VCN_IP_ADDRESS", "PATH", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type attribute_name: str

        :param attribute_value:
            The value to assign to the attribute_value property of this PathMatchCondition.
        :type attribute_value: str

        :param operator:
            The value to assign to the operator property of this PathMatchCondition.
            Allowed values for this property are: "EXACT_MATCH", "FORCE_LONGEST_PREFIX_MATCH", "PREFIX_MATCH", "SUFFIX_MATCH", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type operator: str

        """
        self.swagger_types = {
            'attribute_name': 'str',
            'attribute_value': 'str',
            'operator': 'str'
        }

        self.attribute_map = {
            'attribute_name': 'attributeName',
            'attribute_value': 'attributeValue',
            'operator': 'operator'
        }

        self._attribute_name = None
        self._attribute_value = None
        self._operator = None
        self._attribute_name = 'PATH'

    @property
    def attribute_value(self):
        """
        **[Required]** Gets the attribute_value of this PathMatchCondition.
        The path string that the redirection rule applies to.

        Example: `/example`


        :return: The attribute_value of this PathMatchCondition.
        :rtype: str
        """
        return self._attribute_value

    @attribute_value.setter
    def attribute_value(self, attribute_value):
        """
        Sets the attribute_value of this PathMatchCondition.
        The path string that the redirection rule applies to.

        Example: `/example`


        :param attribute_value: The attribute_value of this PathMatchCondition.
        :type: str
        """
        self._attribute_value = attribute_value

    @property
    def operator(self):
        """
        **[Required]** Gets the operator of this PathMatchCondition.
        A string that specifies how to compare the PathMatchCondition object's `attributeValue` string to the
        incoming URI.

        *  **EXACT_MATCH** - The incoming URI path must exactly and completely match the `attributeValue` string.

        *  **FORCE_LONGEST_PREFIX_MATCH** - The system looks for the `attributeValue` string with the best,
           longest match of the beginning portion of the incoming URI path.

        *  **PREFIX_MATCH** - The beginning portion of the incoming URI path must exactly match the
           `attributeValue` string.

        *  **SUFFIX_MATCH** - The ending portion of the incoming URI path must exactly match the `attributeValue`
           string.

        Allowed values for this property are: "EXACT_MATCH", "FORCE_LONGEST_PREFIX_MATCH", "PREFIX_MATCH", "SUFFIX_MATCH", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The operator of this PathMatchCondition.
        :rtype: str
        """
        return self._operator

    @operator.setter
    def operator(self, operator):
        """
        Sets the operator of this PathMatchCondition.
        A string that specifies how to compare the PathMatchCondition object's `attributeValue` string to the
        incoming URI.

        *  **EXACT_MATCH** - The incoming URI path must exactly and completely match the `attributeValue` string.

        *  **FORCE_LONGEST_PREFIX_MATCH** - The system looks for the `attributeValue` string with the best,
           longest match of the beginning portion of the incoming URI path.

        *  **PREFIX_MATCH** - The beginning portion of the incoming URI path must exactly match the
           `attributeValue` string.

        *  **SUFFIX_MATCH** - The ending portion of the incoming URI path must exactly match the `attributeValue`
           string.


        :param operator: The operator of this PathMatchCondition.
        :type: str
        """
        allowed_values = ["EXACT_MATCH", "FORCE_LONGEST_PREFIX_MATCH", "PREFIX_MATCH", "SUFFIX_MATCH"]
        if not value_allowed_none_or_none_sentinel(operator, allowed_values):
            operator = 'UNKNOWN_ENUM_VALUE'
        self._operator = operator

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class GlossarySummary(object):
    """
    Summary of a glossary. A glossary of business terms, such as 'Customer', 'Account', 'Contact', 'Address',
    or 'Product', with definitions, used to provide common meaning across disparate data assets. Business glossaries
    may be hierarchical where some terms may contain child terms to allow them to be used as 'taxonomies'.
    By linking data assets, data entities, and attributes to glossaries and glossary terms, the glossary can act as a
    way of organizing data catalog objects in a hierarchy to make a large number of objects more navigable and easier to
    consume. Objects in the data catalog, such as data assets or data entities, may be linked to any level in the
    glossary, so that the glossary can be used to browse the available data according to the business model of the
    organization.
    """

    #: A constant which can be used with the workflow_status property of a GlossarySummary.
    #: This constant has a value of "NEW"
    WORKFLOW_STATUS_NEW = "NEW"

    #: A constant which can be used with the workflow_status property of a GlossarySummary.
    #: This constant has a value of "APPROVED"
    WORKFLOW_STATUS_APPROVED = "APPROVED"

    #: A constant which can be used with the workflow_status property of a GlossarySummary.
    #: This constant has a value of "UNDER_REVIEW"
    WORKFLOW_STATUS_UNDER_REVIEW = "UNDER_REVIEW"

    #: A constant which can be used with the workflow_status property of a GlossarySummary.
    #: This constant has a value of "ESCALATED"
    WORKFLOW_STATUS_ESCALATED = "ESCALATED"

    #: A constant which can be used with the lifecycle_state property of a GlossarySummary.
    #: This constant has a value of "CREATING"
    LIFECYCLE_STATE_CREATING = "CREATING"

    #: A constant which can be used with the lifecycle_state property of a GlossarySummary.
    #: This constant has a value of "ACTIVE"
    LIFECYCLE_STATE_ACTIVE = "ACTIVE"

    #: A constant which can be used with the lifecycle_state property of a GlossarySummary.
    #: This constant has a value of "INACTIVE"
    LIFECYCLE_STATE_INACTIVE = "INACTIVE"

    #: A constant which can be used with the lifecycle_state property of a GlossarySummary.
    #: This constant has a value of "UPDATING"
    LIFECYCLE_STATE_UPDATING = "UPDATING"

    #: A constant which can be used with the lifecycle_state property of a GlossarySummary.
    #: This constant has a value of "DELETING"
    LIFECYCLE_STATE_DELETING = "DELETING"

    #: A constant which can be used with the lifecycle_state property of a GlossarySummary.
    #: This constant has a value of "DELETED"
    LIFECYCLE_STATE_DELETED = "DELETED"

    #: A constant which can be used with the lifecycle_state property of a GlossarySummary.
    #: This constant has a value of "FAILED"
    LIFECYCLE_STATE_FAILED = "FAILED"

    #: A constant which can be used with the lifecycle_state property of a GlossarySummary.
    #: This constant has a value of "MOVING"
    LIFECYCLE_STATE_MOVING = "MOVING"

    def __init__(self, **kwargs):
        """
        Initializes a new GlossarySummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param key:
            The value to assign to the key property of this GlossarySummary.
        :type key: str

        :param display_name:
            The value to assign to the display_name property of this GlossarySummary.
        :type display_name: str

        :param catalog_id:
            The value to assign to the catalog_id property of this GlossarySummary.
        :type catalog_id: str

        :param time_created:
            The value to assign to the time_created property of this GlossarySummary.
        :type time_created: datetime

        :param description:
            The value to assign to the description property of this GlossarySummary.
        :type description: str

        :param uri:
            The value to assign to the uri property of this GlossarySummary.
        :type uri: str

        :param workflow_status:
            The value to assign to the workflow_status property of this GlossarySummary.
            Allowed values for this property are: "NEW", "APPROVED", "UNDER_REVIEW", "ESCALATED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type workflow_status: str

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this GlossarySummary.
            Allowed values for this property are: "CREATING", "ACTIVE", "INACTIVE", "UPDATING", "DELETING", "DELETED", "FAILED", "MOVING", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param import_job_definition_key:
            The value to assign to the import_job_definition_key property of this GlossarySummary.
        :type import_job_definition_key: str

        :param import_job_key:
            The value to assign to the import_job_key property of this GlossarySummary.
        :type import_job_key: str

        :param latest_import_job_execution_key:
            The value to assign to the latest_import_job_execution_key property of this GlossarySummary.
        :type latest_import_job_execution_key: str

        :param latest_import_job_execution_status:
            The value to assign to the latest_import_job_execution_status property of this GlossarySummary.
        :type latest_import_job_execution_status: str

        """
        self.swagger_types = {
            'key': 'str',
            'display_name': 'str',
            'catalog_id': 'str',
            'time_created': 'datetime',
            'description': 'str',
            'uri': 'str',
            'workflow_status': 'str',
            'lifecycle_state': 'str',
            'import_job_definition_key': 'str',
            'import_job_key': 'str',
            'latest_import_job_execution_key': 'str',
            'latest_import_job_execution_status': 'str'
        }

        self.attribute_map = {
            'key': 'key',
            'display_name': 'displayName',
            'catalog_id': 'catalogId',
            'time_created': 'timeCreated',
            'description': 'description',
            'uri': 'uri',
            'workflow_status': 'workflowStatus',
            'lifecycle_state': 'lifecycleState',
            'import_job_definition_key': 'importJobDefinitionKey',
            'import_job_key': 'importJobKey',
            'latest_import_job_execution_key': 'latestImportJobExecutionKey',
            'latest_import_job_execution_status': 'latestImportJobExecutionStatus'
        }

        self._key = None
        self._display_name = None
        self._catalog_id = None
        self._time_created = None
        self._description = None
        self._uri = None
        self._workflow_status = None
        self._lifecycle_state = None
        self._import_job_definition_key = None
        self._import_job_key = None
        self._latest_import_job_execution_key = None
        self._latest_import_job_execution_status = None

    @property
    def key(self):
        """
        **[Required]** Gets the key of this GlossarySummary.
        Unique glossary key that is immutable.


        :return: The key of this GlossarySummary.
        :rtype: str
        """
        return self._key

    @key.setter
    def key(self, key):
        """
        Sets the key of this GlossarySummary.
        Unique glossary key that is immutable.


        :param key: The key of this GlossarySummary.
        :type: str
        """
        self._key = key

    @property
    def display_name(self):
        """
        Gets the display_name of this GlossarySummary.
        A user-friendly display name. Does not have to be unique, and it's changeable.
        Avoid entering confidential information.


        :return: The display_name of this GlossarySummary.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this GlossarySummary.
        A user-friendly display name. Does not have to be unique, and it's changeable.
        Avoid entering confidential information.


        :param display_name: The display_name of this GlossarySummary.
        :type: str
        """
        self._display_name = display_name

    @property
    def catalog_id(self):
        """
        Gets the catalog_id of this GlossarySummary.
        The data catalog's OCID.


        :return: The catalog_id of this GlossarySummary.
        :rtype: str
        """
        return self._catalog_id

    @catalog_id.setter
    def catalog_id(self, catalog_id):
        """
        Sets the catalog_id of this GlossarySummary.
        The data catalog's OCID.


        :param catalog_id: The catalog_id of this GlossarySummary.
        :type: str
        """
        self._catalog_id = catalog_id

    @property
    def time_created(self):
        """
        Gets the time_created of this GlossarySummary.
        The date and time the glossary was created, in the format defined by `RFC3339`__.
        Example: `2019-03-25T21:10:29.600Z`

        __ https://tools.ietf.org/html/rfc3339


        :return: The time_created of this GlossarySummary.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this GlossarySummary.
        The date and time the glossary was created, in the format defined by `RFC3339`__.
        Example: `2019-03-25T21:10:29.600Z`

        __ https://tools.ietf.org/html/rfc3339


        :param time_created: The time_created of this GlossarySummary.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def description(self):
        """
        Gets the description of this GlossarySummary.
        Detailed description of the glossary.


        :return: The description of this GlossarySummary.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this GlossarySummary.
        Detailed description of the glossary.


        :param description: The description of this GlossarySummary.
        :type: str
        """
        self._description = description

    @property
    def uri(self):
        """
        Gets the uri of this GlossarySummary.
        URI to the glossary instance in the API.


        :return: The uri of this GlossarySummary.
        :rtype: str
        """
        return self._uri

    @uri.setter
    def uri(self, uri):
        """
        Sets the uri of this GlossarySummary.
        URI to the glossary instance in the API.


        :param uri: The uri of this GlossarySummary.
        :type: str
        """
        self._uri = uri

    @property
    def workflow_status(self):
        """
        Gets the workflow_status of this GlossarySummary.
        Status of the approval process workflow for this business glossary.

        Allowed values for this property are: "NEW", "APPROVED", "UNDER_REVIEW", "ESCALATED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The workflow_status of this GlossarySummary.
        :rtype: str
        """
        return self._workflow_status

    @workflow_status.setter
    def workflow_status(self, workflow_status):
        """
        Sets the workflow_status of this GlossarySummary.
        Status of the approval process workflow for this business glossary.


        :param workflow_status: The workflow_status of this GlossarySummary.
        :type: str
        """
        allowed_values = ["NEW", "APPROVED", "UNDER_REVIEW", "ESCALATED"]
        if not value_allowed_none_or_none_sentinel(workflow_status, allowed_values):
            workflow_status = 'UNKNOWN_ENUM_VALUE'
        self._workflow_status = workflow_status

    @property
    def lifecycle_state(self):
        """
        Gets the lifecycle_state of this GlossarySummary.
        State of the Glossary.

        Allowed values for this property are: "CREATING", "ACTIVE", "INACTIVE", "UPDATING", "DELETING", "DELETED", "FAILED", "MOVING", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this GlossarySummary.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this GlossarySummary.
        State of the Glossary.


        :param lifecycle_state: The lifecycle_state of this GlossarySummary.
        :type: str
        """
        allowed_values = ["CREATING", "ACTIVE", "INACTIVE", "UPDATING", "DELETING", "DELETED", "FAILED", "MOVING"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    @property
    def import_job_definition_key(self):
        """
        Gets the import_job_definition_key of this GlossarySummary.
        The unique key of the job definition resource that was used in the Glossary import.


        :return: The import_job_definition_key of this GlossarySummary.
        :rtype: str
        """
        return self._import_job_definition_key

    @import_job_definition_key.setter
    def import_job_definition_key(self, import_job_definition_key):
        """
        Sets the import_job_definition_key of this GlossarySummary.
        The unique key of the job definition resource that was used in the Glossary import.


        :param import_job_definition_key: The import_job_definition_key of this GlossarySummary.
        :type: str
        """
        self._import_job_definition_key = import_job_definition_key

    @property
    def import_job_key(self):
        """
        Gets the import_job_key of this GlossarySummary.
        The unique key of the job policy for Glossary import.


        :return: The import_job_key of this GlossarySummary.
        :rtype: str
        """
        return self._import_job_key

    @import_job_key.setter
    def import_job_key(self, import_job_key):
        """
        Sets the import_job_key of this GlossarySummary.
        The unique key of the job policy for Glossary import.


        :param import_job_key: The import_job_key of this GlossarySummary.
        :type: str
        """
        self._import_job_key = import_job_key

    @property
    def latest_import_job_execution_key(self):
        """
        Gets the latest_import_job_execution_key of this GlossarySummary.
        The unique key of the parent job execution for which the log resource was created.


        :return: The latest_import_job_execution_key of this GlossarySummary.
        :rtype: str
        """
        return self._latest_import_job_execution_key

    @latest_import_job_execution_key.setter
    def latest_import_job_execution_key(self, latest_import_job_execution_key):
        """
        Sets the latest_import_job_execution_key of this GlossarySummary.
        The unique key of the parent job execution for which the log resource was created.


        :param latest_import_job_execution_key: The latest_import_job_execution_key of this GlossarySummary.
        :type: str
        """
        self._latest_import_job_execution_key = latest_import_job_execution_key

    @property
    def latest_import_job_execution_status(self):
        """
        Gets the latest_import_job_execution_status of this GlossarySummary.
        Status of the latest glossary import job execution, such as running, paused, or completed.
        This may include additional information like time import started , import file size and % of completion


        :return: The latest_import_job_execution_status of this GlossarySummary.
        :rtype: str
        """
        return self._latest_import_job_execution_status

    @latest_import_job_execution_status.setter
    def latest_import_job_execution_status(self, latest_import_job_execution_status):
        """
        Sets the latest_import_job_execution_status of this GlossarySummary.
        Status of the latest glossary import job execution, such as running, paused, or completed.
        This may include additional information like time import started , import file size and % of completion


        :param latest_import_job_execution_status: The latest_import_job_execution_status of this GlossarySummary.
        :type: str
        """
        self._latest_import_job_execution_status = latest_import_job_execution_status

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other
